@@ -62,17 +62,20 @@
     (lambda* (dur freq amp (fm-index 1.0) (amp-env '(0 0 25 1 75 1 100 0)))
       (let* ((frq-scl (hz->radians freq))
 	     (maxdev (* frq-scl fm-index))
-	     (index1 (* maxdev (/ 5.0 (log freq))))
-	     (index2 (/ (* maxdev 3.0 (- 8.5 (log freq))) (+ 3.0 (/ freq 1000))))
-	     (index3 (* maxdev (/ 4.0 (sqrt freq))))
 	     (carrier (make-oscil :frequency freq))
 	     (fmosc1 (make-oscil :frequency freq))
 	     (fmosc2 (make-oscil :frequency (* 3 freq)))
 	     (fmosc3 (make-oscil :frequency (* 4 freq)))
-	     (ampf  (make-env :envelope amp-env :scaler amp :duration dur))
-	     (indf1 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index1 :duration dur))
-	     (indf2 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index2 :duration dur))
-	     (indf3 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index3 :duration dur))
+	     (ampf (make-env :envelope amp-env :scaler amp :duration dur))
+	     (indf1 (make-env :envelope '(0 1 25 0.4 75 0.6000000000000001 100 0) 
+			      :scaler (* maxdev (/ 5.0 (log freq)))
+			      :duration dur))
+	     (indf2 (make-env :envelope '(0 1 25 0.4 75 0.6000000000000001 100 0) 
+			      :scaler (/ (* maxdev 3.0 (- 8.5 (log freq))) (+ 3.0 (/ freq 1000)))
+			      :duration dur))
+	     (indf3 (make-env :envelope '(0 1 25 0.4 75 0.6000000000000001 100 0) 
+			      :scaler (* maxdev (/ 4.0 (sqrt freq)))
+			      :duration dur))
 	     (pervib (make-triangle-wave :frequency 5 :amplitude (* 0.0025 frq-scl)))
 	     (ranvib (make-rand-interp :frequency 16 :amplitude (* 0.005 frq-scl))))
 	(lambda ()
@@ -90,15 +93,8 @@
 (define* (make-float-vector-test (srate *clm-srate*)
 			(bufsize *clm-rt-bufsize*)
 			(sample-type *clm-sample-type*))
-  (let ((vmode (vector 0 12 2 4 14 4 5 5 0 7 7 11 11))
-	(vpits (make-vector (+ 1 lim) 0))
-	(vbegs (make-vector (+ 1 lim) 0))
-	(cellbeg 0)
-	(cellsiz 6)
-	(cellctr 0)
-	(func #f)
-	(len 0)
-	(dur 0.0))
+  (let ((vpits (make-vector (+ 1 lim) 0))
+	(vbegs (make-vector (+ 1 lim) 0)))
     (do ((i 0 (+ 1 i)))
 	((= i lim))
       (set! (vpits i) (random 12))
@@ -106,35 +102,42 @@
     (set! *clm-srate* srate)
     (set! *clm-rt-bufsize* bufsize)
     (set! *output* (mus-audio-open-output mus-audio-default srate 1 sample-type (* bufsize 2)))
-    (lambda ()
-      (if (> len 1)
-	  (set! len (- len 1))
-	  (begin
-	    (set! dur (* ctempo (vbegs (+ cellctr 1))))
-	    (set! cellctr (+ cellctr 1))
-	    (if (> cellctr (+ cellsiz cellbeg))
-		(begin
-		  (if (> (random 1.0) 0.5) (set! cellbeg (+ 1 cellbeg)))
-		  (if (> (random 1.0) 0.5) (set! cellsiz (+ 1 cellsiz)))
-		  (set! cellctr cellbeg)))
 
-	    (let ((freq (* cfreq 16.351 16
-			   (expt 2 (/ (vmode (vpits cellctr)) 12.0)))))
-	      (format () "dur: ~A, freq: ~A, amp: ~A, index: ~A~%"
-		      dur
-		      (if (< (* 8 freq) *clm-srate*)
-			  freq
-			  (/ freq 4))
-		      (* camp 0.3) 
-		      cindex)
-
-	      (set! func (make-rt-violin dur
-					 (if (< (* 8 freq) *clm-srate*)
-					     freq
-					     (/ freq 4))
-					 (* camp 0.3) :fm-index cindex)))
-	    (set! len (ceiling (/ (seconds->samples dur) bufsize)))))
-      func)))
+    (let ((cellbeg 0)
+	  (cellsiz 6)
+	  (cellctr 0)
+	  (func #f)
+	  (len 0)
+	  (dur 0.0)
+	  (vmode (vector 0 12 2 4 14 4 5 5 0 7 7 11 11)))
+      (lambda ()
+	(if (> len 1)
+	    (set! len (- len 1))
+	    (begin
+	      (set! dur (* ctempo (vbegs (+ cellctr 1))))
+	      (set! cellctr (+ cellctr 1))
+	      (if (> cellctr (+ cellsiz cellbeg))
+		  (begin
+		    (if (> (random 1.0) 0.5) (set! cellbeg (+ 1 cellbeg)))
+		    (if (> (random 1.0) 0.5) (set! cellsiz (+ 1 cellsiz)))
+		    (set! cellctr cellbeg)))
+	      
+	      (let ((freq (* cfreq 16.351 16
+			     (expt 2 (/ (vmode (vpits cellctr)) 12.0)))))
+		(format () "dur: ~A, freq: ~A, amp: ~A, index: ~A~%"
+			dur
+			(if (< (* 8 freq) *clm-srate*)
+			    freq
+			    (/ freq 4))
+			(* camp 0.3) 
+			cindex)
+		(set! func (make-rt-violin dur
+					   (if (< (* 8 freq) *clm-srate*)
+					       freq
+					       (/ freq 4))
+					   (* camp 0.3) :fm-index cindex)))
+	      (set! len (ceiling (/ (seconds->samples dur) bufsize)))))
+	func))))
 
 ;; from clm-2/bess5.cl and clm-2/clm-example.lisp
 (define time 60)
@@ -159,6 +162,18 @@
 (define* (make-agn (srate *clm-srate*)
 		   (bufsize *clm-rt-bufsize*)
 		   (sample-type *clm-sample-type*))
+  (do ((i 0 (+ i 1)))
+      ((= i lim))
+    (set! (octs i) (floor (+ 4 (* 2 (rbell (random 1.0))))))
+    (set! (pits i) (mode (random 12)))
+    (set! (rhys i) (+ 4 (random 6)))
+    (set! (begs i) (if (< (random 1.0) 0.9) 
+		       (+ 4 (random 2))
+		       (random 24)))
+    (set! (amps i) (floor (+ 1 (* 8 (rbell (random 1.0)))))))
+  (set! *clm-srate* srate)
+  (set! *clm-rt-bufsize* bufsize)
+  (set! *output* (mus-audio-open-output mus-audio-default srate 1 sample-type (* bufsize 2)))
   (let ((wins (vector '(0 0 40 0.1 60 0.2 75 0.4 82 1 90 1 100 0)
 		      '(0 0 60 0.1 80 0.2 90 0.4 95 1 100 0)
 		      '(0 0 10 1 16 0 32 0.1 50 1 56 0 60 0 90 0.3 100 0)
@@ -181,18 +196,6 @@
 	(whichway 1)
 	(func #f)
 	(len 0))
-    (do ((i 0 (+ i 1)))
-	((= i lim))
-      (set! (octs i) (floor (+ 4 (* 2 (rbell (random 1.0))))))
-      (set! (pits i) (mode (random 12)))
-      (set! (rhys i) (+ 4 (random 6)))
-      (set! (begs i) (if (< (random 1.0) 0.9) 
-			 (+ 4 (random 2))
-			 (random 24)))
-      (set! (amps i) (floor (+ 1 (* 8 (rbell (random 1.0)))))))
-    (set! *clm-srate* srate)
-    (set! *clm-rt-bufsize* bufsize)
-    (set! *output* (mus-audio-open-output mus-audio-default srate 1 sample-type (* bufsize 2)))
     (lambda ()
       (if (> len 1)
 	  (set! len (- len 1))
@@ -318,23 +321,23 @@
 						     XmNtopAttachment    XmATTACH_FORM
 						     XmNrightAttachment  XmATTACH_FORM
 						     XmNbackground       (get-color background))))
-	   (sep (XtCreateManagedWidget "sep" xmSeparatorWidgetClass form
-				       (list XmNleftAttachment   XmATTACH_FORM
-					     XmNbottomAttachment XmATTACH_NONE
-					     XmNtopAttachment    XmATTACH_WIDGET
-					     XmNtopWidget        radio
-					     XmNrightAttachment  XmATTACH_FORM
-					     XmNheight 4
-					     XmNorientation XmHORIZONTAL)))
-	   ;; tempo
-	   (tempo (XtCreateManagedWidget " tempo:" xmLabelWidgetClass form
-					 (list XmNleftAttachment   XmATTACH_FORM
-					       XmNbottomAttachment XmATTACH_NONE
-					       XmNtopAttachment    XmATTACH_WIDGET
-					       XmNtopWidget        sep
-					       XmNrightAttachment  XmATTACH_NONE
-					       XmNrecomputeSize    #f
-					       XmNbackground       (get-color background))))
+           (tempo (let ((sep (XtCreateManagedWidget "sep" xmSeparatorWidgetClass form
+						    (list XmNleftAttachment XmATTACH_FORM 
+							  XmNbottomAttachment XmATTACH_NONE
+							  XmNtopAttachment XmATTACH_WIDGET 
+							  XmNtopWidget radio 
+							  XmNrightAttachment XmATTACH_FORM 
+							  XmNheight 4 
+							  XmNorientation XmHORIZONTAL))))
+                    (XtCreateManagedWidget " tempo:" xmLabelWidgetClass form
+					   (list XmNleftAttachment XmATTACH_FORM 
+						 XmNbottomAttachment XmATTACH_NONE 
+						 XmNtopAttachment XmATTACH_WIDGET 
+						 XmNtopWidget sep 
+						 XmNrightAttachment XmATTACH_NONE 
+						 XmNrecomputeSize #f
+						 XmNbackground (get-color background)))))
+
 	   (tempo-label (XtCreateManagedWidget "label" xmLabelWidgetClass form
 					       (list XmNleftAttachment   XmATTACH_WIDGET
 						     XmNleftWidget       tempo
@@ -410,23 +413,22 @@
 						   XmNorientation      XmHORIZONTAL
 						   XmNheight           20
 						   XmNbackground       light-blue)))
-	   ;; index
-	   (index (XtCreateManagedWidget " index:" xmLabelWidgetClass form
-					 (list XmNleftAttachment   XmATTACH_FORM
-					       XmNbottomAttachment XmATTACH_NONE
-					       XmNtopAttachment    XmATTACH_WIDGET
-					       XmNtopWidget        amp
-					       XmNrightAttachment  XmATTACH_NONE
-					       XmNrecomputeSize    #f
-					       XmNbackground       (get-color background))))
-	   (index-label (XtCreateManagedWidget "label" xmLabelWidgetClass form
-					       (list XmNleftAttachment   XmATTACH_WIDGET
-						     XmNleftWidget       index
-						     XmNbottomAttachment XmATTACH_NONE
-						     XmNtopAttachment    XmATTACH_OPPOSITE_WIDGET
-						     XmNtopWidget        index
-						     XmNrightAttachment  XmATTACH_NONE
-						     XmNbackground       (get-color background))))
+	   (index-label (let ((index (XtCreateManagedWidget " index:" xmLabelWidgetClass form
+							    (list XmNleftAttachment   XmATTACH_FORM
+								  XmNbottomAttachment XmATTACH_NONE
+								  XmNtopAttachment    XmATTACH_WIDGET
+								  XmNtopWidget        amp
+								  XmNrightAttachment  XmATTACH_NONE
+								  XmNrecomputeSize    #f
+								  XmNbackground       (get-color background)))))
+			  (XtCreateManagedWidget "label" xmLabelWidgetClass form
+						 (list XmNleftAttachment   XmATTACH_WIDGET
+						       XmNleftWidget       index
+						       XmNbottomAttachment XmATTACH_NONE
+						       XmNtopAttachment    XmATTACH_OPPOSITE_WIDGET
+						       XmNtopWidget        index
+						       XmNrightAttachment  XmATTACH_NONE
+						       XmNbackground       (get-color background)))))
 	   (index-scale (XtCreateManagedWidget "index" xmScaleWidgetClass form
 					       (list XmNleftAttachment   XmATTACH_WIDGET
 						     XmNleftWidget       index-label
@@ -437,95 +439,95 @@
 						     XmNshowValue        #f
 						     XmNorientation      XmHORIZONTAL
 						     XmNheight           20
-						     XmNbackground       light-blue)))
-	   (low-tempo 0.05)
-	   (high-tempo 0.5)
-	   (low-freq 0.1)
-	   (high-freq 4.0)
-	   (high-index 2.0)
-	   (which-play 0)
-	   (proc #f)
-	   (func #f))
-
-      (define (tempo-callback w c i)
-	(set! ctempo (+ low-tempo (* (.value i) (/ (- high-tempo low-tempo) 100.0))))
-	(set-flabel tempo-label ctempo))
-
-      (define (amp-callback w c i)
-	(let ((high-amp 1.0))
-	  (set! camp (* (.value i) (/ high-amp 100.0))))
-	(set-flabel amp-label camp))
-
-      (define (freq-callback w c i)
-	(set! cfreq (+ low-freq (* (.value i) (/ (- high-freq low-freq) 100.0))))
-	(set-flabel freq-label cfreq))
-
-      (define (index-callback w c i)
-	(set! cindex (* (.value i) (/ high-index 100.0)))
-	(set-flabel index-label cindex))
-
-      (define (set-defaults)
-	(set! ctempo 0.25)
-	(set! camp 1.0)
-	(set! cfreq 1.0)
-	(set! cindex 1.0)
-	(set-flabel tempo-label ctempo)
-	(set-flabel amp-label camp)
-	(set-flabel freq-label cfreq)
-	(set-flabel index-label cindex)
-	(XmScaleSetValue tempo-scale (floor (* 100 (/ (- ctempo low-tempo) (- high-tempo low-tempo)))))
-	(XmScaleSetValue freq-scale (floor (* 100 (/ (- cfreq low-freq) (- high-freq low-freq)))))
-	(XmScaleSetValue amp-scale (floor (* 100 camp)))
-	(XmScaleSetValue index-scale (floor (* 100 (/ cindex high-index)))))
-
-      (XtManageChild radio)
-      ;; add scale-change (drag and value-changed) callbacks
-      (XtAddCallback tempo-scale XmNdragCallback tempo-callback)
-      (XtAddCallback tempo-scale XmNvalueChangedCallback tempo-callback)
-
-      (XtAddCallback amp-scale XmNdragCallback amp-callback)
-      (XtAddCallback amp-scale XmNvalueChangedCallback amp-callback)
-
-      (XtAddCallback freq-scale XmNdragCallback freq-callback)
-      (XtAddCallback freq-scale XmNvalueChangedCallback freq-callback)
-
-      (XtAddCallback index-scale XmNdragCallback index-callback)
-      (XtAddCallback index-scale XmNvalueChangedCallback index-callback)
-
-      (XtAddCallback agn-button XmNvalueChangedCallback
-		     (lambda (w c i)
-		       (if (.set i)
-			   (set! which-play 0))
-		       (set! cplay #f)
-		       (XmToggleButtonSetState play-button cplay #f)))
-
-      (XmToggleButtonSetState agn-button #t #f)
-      (XtAddCallback test-button XmNvalueChangedCallback
-		     (lambda (w c i)
-		       (if (.set i)
-			   (set! which-play 1))
-		       (set! cplay #f)
-		       (XmToggleButtonSetState play-button cplay #f)))
-		     
-      (XtAddCallback quit-button XmNactivateCallback
-		     (lambda (w c i)
-		       (set! cplay #f)
-		       (if proc (XtRemoveWorkProc proc))
-		       (exit 0)))
-      
-      (XtAddCallback play-button XmNvalueChangedCallback
-		     (lambda (w c i)
-		       (set! cplay (.set i))
-		       (if cplay
-			   (begin
-			     (set-defaults)
-			     (set! func (apply (if (= which-play 0) make-agn make-float-vector-test) (or args ())))
-			     (set! proc (XtAppAddWorkProc app (lambda (c) (rt-send->dac func)))))
-			   (if proc (XtRemoveWorkProc proc)))))
-      (XmToggleButtonSetState play-button cplay #f)
-      (set-defaults)
-      (XtRealizeWidget shell))
-    (XtAppMainLoop app)))
+						     XmNbackground       light-blue))))
+      (let ((low-tempo 0.05)
+	    (high-tempo 0.5)
+	    (low-freq 0.1)
+	    (high-freq 4.0)
+	    (high-index 2.0)
+	    (which-play 0)
+	    (proc #f)
+	    (func #f))
+	
+	(define (tempo-callback w c i)
+	  (set! ctempo (+ low-tempo (* (.value i) (/ (- high-tempo low-tempo) 100.0))))
+	  (set-flabel tempo-label ctempo))
+	
+	(define (amp-callback w c i)
+	  (let ((high-amp 1.0))
+	    (set! camp (* (.value i) (/ high-amp 100.0))))
+	  (set-flabel amp-label camp))
+	
+	(define (freq-callback w c i)
+	  (set! cfreq (+ low-freq (* (.value i) (/ (- high-freq low-freq) 100.0))))
+	  (set-flabel freq-label cfreq))
+	
+	(define (index-callback w c i)
+	  (set! cindex (* (.value i) (/ high-index 100.0)))
+	  (set-flabel index-label cindex))
+	
+	(define (set-defaults)
+	  (set! ctempo 0.25)
+	  (set! camp 1.0)
+	  (set! cfreq 1.0)
+	  (set! cindex 1.0)
+	  (set-flabel tempo-label ctempo)
+	  (set-flabel amp-label camp)
+	  (set-flabel freq-label cfreq)
+	  (set-flabel index-label cindex)
+	  (XmScaleSetValue tempo-scale (floor (* 100 (/ (- ctempo low-tempo) (- high-tempo low-tempo)))))
+	  (XmScaleSetValue freq-scale (floor (* 100 (/ (- cfreq low-freq) (- high-freq low-freq)))))
+	  (XmScaleSetValue amp-scale (floor (* 100 camp)))
+	  (XmScaleSetValue index-scale (floor (* 100 (/ cindex high-index)))))
+	
+	(XtManageChild radio)
+	;; add scale-change (drag and value-changed) callbacks
+	(XtAddCallback tempo-scale XmNdragCallback tempo-callback)
+	(XtAddCallback tempo-scale XmNvalueChangedCallback tempo-callback)
+	
+	(XtAddCallback amp-scale XmNdragCallback amp-callback)
+	(XtAddCallback amp-scale XmNvalueChangedCallback amp-callback)
+	
+	(XtAddCallback freq-scale XmNdragCallback freq-callback)
+	(XtAddCallback freq-scale XmNvalueChangedCallback freq-callback)
+	
+	(XtAddCallback index-scale XmNdragCallback index-callback)
+	(XtAddCallback index-scale XmNvalueChangedCallback index-callback)
+	
+	(XtAddCallback agn-button XmNvalueChangedCallback
+		       (lambda (w c i)
+			 (if (.set i)
+			     (set! which-play 0))
+			 (set! cplay #f)
+			 (XmToggleButtonSetState play-button cplay #f)))
+	
+	(XmToggleButtonSetState agn-button #t #f)
+	(XtAddCallback test-button XmNvalueChangedCallback
+		       (lambda (w c i)
+			 (if (.set i)
+			     (set! which-play 1))
+			 (set! cplay #f)
+			 (XmToggleButtonSetState play-button cplay #f)))
+	
+	(XtAddCallback quit-button XmNactivateCallback
+		       (lambda (w c i)
+			 (set! cplay #f)
+			 (if proc (XtRemoveWorkProc proc))
+			 (exit 0)))
+	
+	(XtAddCallback play-button XmNvalueChangedCallback
+		       (lambda (w c i)
+			 (set! cplay (.set i))
+			 (if cplay
+			     (begin
+			       (set-defaults)
+			       (set! func (apply (if (= which-play 0) make-agn make-float-vector-test) (or args ())))
+			       (set! proc (XtAppAddWorkProc app (lambda (c) (rt-send->dac func)))))
+			     (if proc (XtRemoveWorkProc proc)))))
+	(XmToggleButtonSetState play-button cplay #f)
+	(set-defaults)
+	(XtRealizeWidget shell))
+      (XtAppMainLoop app))))
 
 (rt-motif)
 )
