@@ -31,53 +31,53 @@
 ;;; -------- single sample clicks
 
 (define* (remove-single-sample-clicks (jump 8) snd chn)
-  (let* ((reader (make-sampler 0 snd chn))
-	 (mx (make-moving-average 16)) ; local average of abs difference
-	 (samp0 0.0)
-	 (samp1 0.0)
-	 (samp2 0.0)
-	 (fixed 0)
-	 (len (framples snd chn))
-	 (block-size (min len 1048576)) ; do edits by blocks rather than sample-at-a-time (saves time, memory etc) 1048576=1024*1024
-	 (block-ctr 0)
-	 (block-beg 0)
-	 (block (make-float-vector block-size))
-	 (block-changed #f))
-     (do ((ctr 0 (+ ctr 1)))
-	 ((= ctr len))
-       (set! samp0 samp1)
-       (set! samp1 samp2)
-       (set! samp2 (next-sample reader))
-       (set! (block block-ctr) samp2)
-       (let* ((df1 (abs (- samp1 samp0)))
-	      (df2 (abs (- samp2 samp1)))
-	      (df3 (abs (- samp2 samp0)))
-	      (local-max (moving-average mx df1)))
-	 (if (and (> df1 (* jump local-max))
-		  (> df2 (* jump local-max))
-		  (or (< df3 local-max)
-		      (and (< df3 (* 2 local-max))
-			   (< (* (- samp2 samp0)
-				 (- samp1 samp0))
-			      0.0))))
-	     (begin
-	       (set! samp1 (* .5 (+ samp0 samp2)))
-	       (set! (block (- block-ctr 1)) samp1)
-	       (set! block-changed #t)
-	       (set! fixed (+ 1 fixed)))))
-       (set! block-ctr (+ 1 block-ctr))
-       (if (>= block-ctr block-size)
-	   (begin
-	     (if block-changed
-		 (begin
-		   (float-vector->channel block block-beg block-size snd chn)
-		   (set! block-changed #f)))
-	     (set! block-beg (- (+ block-beg block-size) 1))
-	     (set! block-ctr 1)
-	     (set! (block 0) samp2))))
-     (if block-changed
-	 (float-vector->channel block block-beg block-ctr snd chn))
-    fixed))
+  (let* ((len (framples snd chn))
+	 (block-size (min len 1048576))) ; do edits by blocks rather than sample-at-a-time (saves time, memory etc) 1048576=1024*1024
+    (let ((reader (make-sampler 0 snd chn))
+	  (mx (make-moving-average 16)) ; local average of abs difference
+	  (samp0 0.0)
+	  (samp1 0.0)
+	  (samp2 0.0)
+	  (fixed 0)
+	  (block-ctr 0)
+	  (block-beg 0)
+	  (block (make-float-vector block-size))
+	  (block-changed #f))
+      (do ((ctr 0 (+ ctr 1)))
+	  ((= ctr len))
+	(set! samp0 samp1)
+	(set! samp1 samp2)
+	(set! samp2 (next-sample reader))
+	(set! (block block-ctr) samp2)
+	(let ((df1 (abs (- samp1 samp0))))
+	  (let ((df2 (abs (- samp2 samp1)))
+		(df3 (abs (- samp2 samp0)))
+		(local-max (moving-average mx df1)))
+	    (if (and (> df1 (* jump local-max))
+		     (> df2 (* jump local-max))
+		     (or (< df3 local-max)
+			 (and (< df3 (* 2 local-max))
+			      (< (* (- samp2 samp0)
+				    (- samp1 samp0))
+				 0.0))))
+		(begin
+		  (set! samp1 (* .5 (+ samp0 samp2)))
+		  (set! (block (- block-ctr 1)) samp1)
+		  (set! block-changed #t)
+		  (set! fixed (+ 1 fixed))))))
+	(set! block-ctr (+ 1 block-ctr))
+	(if (>= block-ctr block-size)
+	    (begin
+	      (if block-changed
+		  (begin
+		    (float-vector->channel block block-beg block-size snd chn)
+		    (set! block-changed #f)))
+	      (set! block-beg (- (+ block-beg block-size) 1))
+	      (set! block-ctr 1)
+	      (set! (block 0) samp2))))
+      (if block-changed
+	  (float-vector->channel block block-beg block-ctr snd chn))
+      fixed)))
 
 (define (test-remove-single-clicks)
   (let ((test (new-sound "test.snd")))
@@ -115,108 +115,106 @@
 ;;; -------- pops
 
 (define* (smooth-float-vector data beg dur)
-  (let* ((y0 (data beg))
-	 (y1 (data (+ beg dur)))
-	 (angle (if (> y1 y0) pi 0.0)) 
-	 (off (* .5 (+ y0 y1))) 
-	 (scale (* 0.5 (abs (- y1 y0))))
-	 (incr (/ pi dur)))
-    (do ((i 0 (+ i 1)))
-	((= i dur))
-      (set! (data (+ beg i)) (+ off (* scale (cos (+ angle (* i incr)))))))))
+  (let ((y0 (data beg))
+	(y1 (data (+ beg dur))))
+    (let ((angle (if (> y1 y0) pi 0.0)) 
+	  (off (* .5 (+ y0 y1))) 
+	  (scale (* 0.5 (abs (- y1 y0))))
+	  (incr (/ pi dur)))
+      (do ((i 0 (+ i 1)))
+	  ((= i dur))
+	(set! (data (+ beg i)) (+ off (* scale (cos (+ angle (* i incr))))))))))
 
 (define* (remove-pops (size 8) snd chn)
-  (let* ((reader (make-sampler 0 snd chn))
-	 (dly0 (make-delay (* 4 size)))
-	 (dly1 (make-delay (* 5 size)))
-	 (mx-ahead (make-moving-average (* 4 size))) ; local average of abs difference ahead of current window
-	 (mx-behind (make-moving-average (* 4 size))) ; local average of abs difference behind current window
-	 (mx (make-moving-average size)) ; local average of abs difference
-
-	 (last-ahead-samp 0.0)
-	 (last-dly0-samp 0.0)
-	 (last-dly1-samp 0.0)
-
-	 (last-case 0)
-	 (fixed 0)
-	 (len (framples snd chn))
-
+  (let* ((len (framples snd chn))
 	 (pad (* 8 size))
-	 (block-size (min (+ len pad) 1048576)) ; 1048576=1024*1024
-	 (block-ctr 0)
-	 (block-beg 0)
-	 (block (make-float-vector block-size))
-	 (block-changed #f))
-    
-     (let ((check-val 0.0)
-	   (check-start 0)
-	   (checker 0)
-	   (checked 0)
-	   (checking #f)
-	   (moving-start #t))
-       (do ((ctr 0 (+ ctr 1)))
-	   ((= ctr len))
-	 (let* ((ahead-samp (next-sample reader))
-		(avg-ahead (moving-average mx-ahead (abs (- ahead-samp last-ahead-samp))))
-		(dly0-samp (delay dly0 ahead-samp))
-		(cur-diff (abs (- dly0-samp last-dly0-samp)))
-		(cur-avg (moving-average mx cur-diff))
-		(dly1-samp (delay dly1 ahead-samp))
-		(avg-behind (moving-average mx-behind (abs (- dly1-samp last-dly1-samp)))))
-	   (set! last-ahead-samp ahead-samp)
-	   (set! last-dly0-samp dly0-samp)
-	   (set! last-dly1-samp dly1-samp)
-	   (set! (block block-ctr) ahead-samp)
-	   (if checking
-	       (begin
-		 (set! checked (+ checked 1))
-		 (if (or (>= checked (* 2 size))
-			 (< cur-avg check-val))
-		     (begin
-		       (set! fixed (+ fixed 1))
-		       (set! checking #f)
-		       (smooth-float-vector block (- check-start block-beg) (+ size checker))
-		       (set! block-changed #t)))
-		 (if moving-start
-		     (begin
-		       (set! moving-start (< cur-diff avg-behind))
-		       (if moving-start
-			   (set! check-start (+ check-start 1)))))
-		 (if (not moving-start)
-		     (set! checker (+ checker 1))))
-	       (if (and (> (- ctr last-case) (* 2 size))
-			(> cur-avg (* 4 avg-ahead))
-			(> cur-avg (* 4 avg-behind)))
-		   ;; possible pop
-		   (begin
-		     (set! check-start (max 0 (- ctr (* 5 size))))
-		     (set! moving-start (< cur-diff avg-behind))
-		     (if moving-start
-			 (set! check-start (+ check-start 1)))
-		     (set! checking #t)
-		     (set! check-val cur-avg)
-		     (set! checker 0)
-		     (set! checked 0)
-		     (set! last-case ctr))))
-	   
-	   (set! block-ctr (+ block-ctr 1))
-	   (if (>= (+ block-ctr pad) block-size)
-	       (begin
-		 (if block-changed
-		     (begin
-		       (float-vector->channel block block-beg (- block-ctr pad) snd chn)
-		       (set! block-changed #f)))
-		 (set! block-beg (- (+ block-beg block-ctr) pad))
-		 (do ((i 0 (+ i 1))
-		      (j (- block-ctr pad) (+ j 1)))
-		     ((= i pad))
-		   (set! (block i) (block j)))
-		 (set! block-ctr pad)))))
-       
-       (if block-changed
-	   (float-vector->channel block block-beg block-ctr snd chn)))
-
-    fixed))
+	 (block-size (min (+ len pad) 1048576))) ; 1048576=1024*1024
+    (let ((reader (make-sampler 0 snd chn))
+	  (dly0 (make-delay (* 4 size)))
+	  (dly1 (make-delay (* 5 size)))
+	  (mx-ahead (make-moving-average (* 4 size))) ; local average of abs difference ahead of current window
+	  (mx-behind (make-moving-average (* 4 size))) ; local average of abs difference behind current window
+	  (mx (make-moving-average size)) ; local average of abs difference
+	  
+	  (last-ahead-samp 0.0)
+	  (last-dly0-samp 0.0)
+	  (last-dly1-samp 0.0)
+	  (last-case 0)
+	  (fixed 0)
+	  (block-ctr 0)
+	  (block-beg 0)
+	  (block (make-float-vector block-size))
+	  (block-changed #f))
+      
+      (let ((check-val 0.0)
+	    (check-start 0)
+	    (checker 0)
+	    (checked 0)
+	    (checking #f)
+	    (moving-start #t))
+	(do ((ctr 0 (+ ctr 1)))
+	    ((= ctr len))
+	  (let* ((ahead-samp (next-sample reader))
+		 (avg-ahead (moving-average mx-ahead (abs (- ahead-samp last-ahead-samp))))
+		 (dly0-samp (delay dly0 ahead-samp))
+		 (cur-diff (abs (- dly0-samp last-dly0-samp)))
+		 (cur-avg (moving-average mx cur-diff))
+		 (dly1-samp (delay dly1 ahead-samp))
+		 (avg-behind (moving-average mx-behind (abs (- dly1-samp last-dly1-samp)))))
+	    (set! last-ahead-samp ahead-samp)
+	    (set! last-dly0-samp dly0-samp)
+	    (set! last-dly1-samp dly1-samp)
+	    (set! (block block-ctr) ahead-samp)
+	    (if checking
+		(begin
+		  (set! checked (+ checked 1))
+		  (if (or (>= checked (* 2 size))
+			  (< cur-avg check-val))
+		      (begin
+			(set! fixed (+ fixed 1))
+			(set! checking #f)
+			(smooth-float-vector block (- check-start block-beg) (+ size checker))
+			(set! block-changed #t)))
+		  (if moving-start
+		      (begin
+			(set! moving-start (< cur-diff avg-behind))
+			(if moving-start
+			    (set! check-start (+ check-start 1)))))
+		  (if (not moving-start)
+		      (set! checker (+ checker 1))))
+		(if (and (> (- ctr last-case) (* 2 size))
+			 (> cur-avg (* 4 avg-ahead))
+			 (> cur-avg (* 4 avg-behind)))
+		    ;; possible pop
+		    (begin
+		      (set! check-start (max 0 (- ctr (* 5 size))))
+		      (set! moving-start (< cur-diff avg-behind))
+		      (if moving-start
+			  (set! check-start (+ check-start 1)))
+		      (set! checking #t)
+		      (set! check-val cur-avg)
+		      (set! checker 0)
+		      (set! checked 0)
+		      (set! last-case ctr))))
+	    
+	    (set! block-ctr (+ block-ctr 1))
+	    (if (>= (+ block-ctr pad) block-size)
+		(begin
+		  (if block-changed
+		      (begin
+			(float-vector->channel block block-beg (- block-ctr pad) snd chn)
+			(set! block-changed #f)))
+		  (set! block-beg (- (+ block-beg block-ctr) pad))
+		  (do ((i 0 (+ i 1))
+		       (j (- block-ctr pad) (+ j 1)))
+		      ((= i pad))
+		    (set! (block i) (block j)))
+		  (set! block-ctr pad)))))
+	
+	(if block-changed
+	    (float-vector->channel block block-beg block-ctr snd chn)))
+      
+      fixed)))
 
 (define (test-remove-pops)
   (new-sound "test.snd")
@@ -325,49 +323,47 @@
 
 
 (define* (tvf-channel snd chn)
-  (let* ((size (framples snd chn))
-	 (avg-data (make-float-vector size))
-	 (ctr 0)
-	 (mx (maxamp snd chn))
-	 (avg-size 8192)
-	 (rd0 (make-sampler 0 snd chn))
-	 (xhat 0.0)
-	 (frm (make-formant :radius (- 1.0 (/ 500.0 (srate snd))) :frequency 600))
-	 (del (make-moving-sum avg-size))
-	 (K 0.0)
+  (let ((size (framples snd chn))
+	(avg-size 8192))
+    (let ((avg-data (make-float-vector size))
+	  (ctr 0)
+	  (mx (maxamp snd chn))
+	  (rd0 (make-sampler 0 snd chn))
+	  (xhat 0.0)
+	  (frm (make-formant :radius (- 1.0 (/ 500.0 (srate snd))) :frequency 600))
+	  (del (make-moving-sum avg-size))
+	  (K 0.0)
+	  (maxg 0.0)
+	  (ming 1000.0)
+	  (maxK 0.0)
+	  (minK 1000.0))
+      
+      (do ((i 0 (+ i 1)))
+	  ((= i avg-size))
+	(moving-sum del (formant frm (rd0))))
+      
+      (map-channel
+       (lambda (datum)
+	 (let ((xhatminus xhat)
+	       (avg (moving-sum del (formant frm (rd0)))))
+	   
+	   (set! K (min 1.0 (+ .1 (/ avg 100.0))))
+	   ;;	 (set! K .5)
+	   
+	   (set! (avg-data ctr) K)
+	   (set! ctr (+ ctr 1))
+	   
+	   (set! maxg (max maxg avg))
+	   (set! ming (min ming avg))
+	   (set! maxK (max maxK K))
+	   (set! minK (min minK K))
+	   
+	   (set! xhat (+ xhatminus
+			 (* K (- datum xhatminus))))
+	   xhatminus))
+       0 size snd chn)
 
-	 (maxg 0.0)
-	 (ming 1000.0)
-	 (maxK 0.0)
-	 (minK 1000.0)
-	 )
-
-    (do ((i 0 (+ i 1)))
-	((= i avg-size))
-      (moving-sum del (formant frm (rd0))))
-
-    (map-channel
-     (lambda (datum)
-       (let ((xhatminus xhat)
-	     (avg (moving-sum del (formant frm (rd0)))))
-
-	 (set! K (min 1.0 (+ .1 (/ avg 100.0))))
-;	 (set! K .5)
-
-	 (set! (avg-data ctr) K)
-	 (set! ctr (+ ctr 1))
-
-	 (set! maxg (max maxg avg))
-	 (set! ming (min ming avg))
-	 (set! maxK (max maxK K))
-	 (set! minK (min minK K))
-
-	 (set! xhat (+ xhatminus
-		       (* K (- datum xhatminus))))
-	 xhatminus))
-     0 size snd chn)
-
-    (scale-channel (/ mx (maxamp snd chn)) snd chn)))
+      (scale-channel (/ mx (maxamp snd chn)) snd chn))))
 
 
 (define* (clean-channel snd chn)
