@@ -703,8 +703,8 @@
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
 	(os (make-oscil freq)))
-    (let* ((sr2 (make-src :srate speed :input (lambda (dir) (oscil os))))
-	   (sr1 (make-src :srate speed :input (lambda (dir) (src sr2)))))
+    (let ((sr1 (let ((sr2 (make-src :srate speed :input (lambda (dir) (oscil os)))))
+		 (make-src :srate speed :input (lambda (dir) (src sr2))))))
       (do ((i start (+ i 1))) ((= i end))
 	(outa i (* amp (src sr1)))))))
 
@@ -885,16 +885,17 @@
   (let ((os (make-oscil freq))
 	(start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
-	(arr (make-float-vector 100))
-	(ctr 0)
-	(dir 1))
+	(arr (make-float-vector 100)))
     (do ((i 0 (+ i 1)))
 	((= i 100))
       (set! (arr i) (* amp (- (* i .01) 0.5))))
     (array->file "testx.data" arr 100 22050 1)
     (fill! arr 0.0)
     (file->array "testx.data" 0 0 100 arr)
-    (do ((i start (+ i 1))) ((= i end))
+    (do ((ctr 0)
+	 (dir 1)
+	 (i start (+ i 1))) 
+	((= i end))
       (outa i (* (arr ctr) (oscil os)))
       (set! ctr (+ ctr dir))
       (if (>= ctr 99) (set! dir -1)
@@ -1467,11 +1468,11 @@
     (if (or (null? loop-data)
 	    (<= (cadr loop-data) (car loop-data)))
 	(error 'no-loop-positions)
-	(let* ((loop-start (car loop-data))
-	       (loop-length (- (+ (cadr loop-data) 1) loop-start))
-	       (sound-section (float-vector-scale! (file->array sound 0 loop-start loop-length (make-float-vector loop-length)) amp))
-	       (tbl (make-table-lookup :frequency (/ (* freq (srate sound)) loop-length)
-				       :wave sound-section)))
+	(let ((tbl (let* ((loop-start (car loop-data))
+			  (loop-length (- (+ (cadr loop-data) 1) loop-start))
+			  (sound-section (float-vector-scale! (file->array sound 0 loop-start loop-length (make-float-vector loop-length)) amp)))
+		     (make-table-lookup :frequency (/ (* freq (srate sound)) loop-length)
+					:wave sound-section))))
 	  ;; "freq" here is how fast we read (transpose) the sound -- 1.0 returns the original
 	  (do ((i beg (+ i 1)))
 	      ((= i end))
@@ -1578,14 +1579,14 @@
   (float-vector 0.0 (hz->radians frequency) (* 1.0 n)))
 
 (define (sndclmdoc-sum-of-odd-sines gen fm)
-  (let* ((a2 (* (gen 0) 0.5))
-	 (n (gen 2))
-	 (den (* n (sin a2)))
-	 (result (if (< (abs den) 1.0e-9)
-		     0.0
-		     (/ (* (sin (* n a2)) 
-			   (sin (* (+ 1 n) a2)))
-			den))))
+  (let ((result (let* ((a2 (* (gen 0) 0.5))
+		       (n (gen 2))
+		       (den (* n (sin a2))))
+		  (if (< (abs den) 1.0e-9)
+		      0.0
+		      (/ (* (sin (* n a2)) 
+			    (sin (* (+ 1 n) a2)))
+			 den)))))
     (set! (gen 0) (+ (gen 0) (gen 1) fm))
     result))
 
@@ -2018,9 +2019,9 @@
     (lambda (gen input)
       (let-set! gen 'input input)
       (with-let gen
-	(let* ((modphase (* ratio phase))
-	       (result (* (exp (* r2 (cos modphase)))
-			  (sin (+ phase (* r1 (sin modphase)))))))
+	(let ((result (let ((modphase (* ratio phase)))
+			(* (exp (* r2 (cos modphase)))
+			   (sin (+ phase (* r1 (sin modphase))))))))
 	  (set! phase (+ phase input freq))
 	  result)))))
 
@@ -2029,9 +2030,9 @@
     (lambda (gen input)
       (let-set! gen 'input input)
       (with-let gen
-	(let* ((modphase (* ratio phase))
-	       (result (* (exp (- (* r1 (cos modphase)) r3))
-			  (sin (+ phase (* r2 (sin modphase)))))))
+	(let ((result (let ((modphase (* ratio phase)))
+			(* (exp (- (* r1 (cos modphase)) r3))
+			   (sin (+ phase (* r2 (sin modphase))))))))
 	  (set! phase (+ phase input freq))
 	  result)))))
 
@@ -2128,11 +2129,11 @@
     (sndclmdoc-tritri 0 1 1000.0 0.5 0.1 0.01) ; sci-fi laser gun
     (sndclmdoc-tritri 1 1 4000.0 0.7 0.1 0.01)) ; a sparrow?
   (with-sound (:srate 22050) (sndclmdoc-shift-pitch 0 3 "oboe.snd" 1108.0)) ; 1.7
-  (let* ((sound "oboe.snd") ; 1.8
-	 (mx (maxamp sound))
-	 (dur (mus-sound-duration sound)))
-    (with-sound (:scaled-to mx :srate 22050) 
-      (sndclmdoc-repitch 0 dur sound 554 1000)))
+  (let ((sound "oboe.snd")) ; 1.8
+    (let ((mx (maxamp sound))
+	  (dur (mus-sound-duration sound)))
+      (with-sound (:scaled-to mx :srate 22050) 
+	(sndclmdoc-repitch 0 dur sound 554 1000))))
   (with-sound () (sndclmdoc-fofins 0 1 270 .2 .001 730 .6 1090 .3 2440 .1)) ; "Ahh"
   (with-sound () ; one of JC's favorite demos
     (sndclmdoc-fofins 0 4 270 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
