@@ -170,50 +170,50 @@ divseg in early versions of CLM and its antecedents in Sambox and Mus10 (linen).
 	    ((and old-dec (not new-dec))
 	     (error 'wrong-number-of-args "stretch-envelope:~A ~A ~A, old-decay but no new-decay?" old-att new-att old-dec))
 	    (else
-	     (let* ((x0 (car fn))
-		    (new-x x0)
-		    (last-x (fn (- (length fn) 2)))
-		    (y0 (cadr fn))
-		    (new-fn (list y0 x0))
-		    (scl (/ (- new-att x0) (max .0001 (- old-att x0)))))
-	       
-	       (if (and (number? old-dec)
-			(= old-dec old-att))
-		   (set! old-dec (* 1e-06 last-x)))
-	       (reverse
-		(let stretch-envelope-1 ((new-fn new-fn)
-					 (old-fn (cddr fn)))
-		  (if (null? old-fn)
-		      new-fn
-		      (let ((x1 (car old-fn))
-			    (y1 (cadr old-fn)))
-			(when (and (< x0 old-att) (>= x1 old-att))
-			  (set! y0 (if (= x1 old-att)
-				       y1
-				       (+ y0 (* (- y1 y0) (/ (- old-att x0) (- x1 x0))))))
-			  (set! x0 old-att)
-			  (set! new-x new-att)
-			  (set! new-fn (cons y0 (cons new-x new-fn)))
-			  (set! scl (if old-dec
-					(/ (- new-dec new-att) (- old-dec old-att))
-					(/ (- last-x new-att) (- last-x old-att)))))
-			(when (and (real? old-dec)
-				   (< x0 old-dec)
-				   (>= x1 old-dec))
-			  (set! y0 (if (= x1 old-dec)
-				       y1
-				       (+ y0 (* (- y1 y0) (/ (- old-dec x0) (- x1 x0))))))
-			  (set! x0 old-dec)
-			  (set! new-x new-dec)
-			  (set! new-fn (cons y0 (cons new-x new-fn)))
-			  (set! scl (/ (- last-x new-dec) (- last-x old-dec))))
-			(unless (= x0 x1)
-			  (set! new-x (+ new-x (* scl (- x1 x0))))
-			  (set! new-fn (cons y1 (cons new-x new-fn)))
-			  (set! x0 x1)
-			  (set! y0 y1))
-			(stretch-envelope-1 new-fn (cddr old-fn))))))))))))
-
+	     (let ((x0 (car fn))
+		   (y0 (cadr fn)))
+	       (let ((new-x x0)
+		     (last-x (fn (- (length fn) 2)))
+		     (new-fn (list y0 x0))
+		     (scl (/ (- new-att x0) (max .0001 (- old-att x0)))))
+		 
+		 (if (and (number? old-dec)
+			  (= old-dec old-att))
+		     (set! old-dec (* 1e-06 last-x)))
+		 (reverse
+		  (let stretch-envelope-1 ((new-fn new-fn)
+					   (old-fn (cddr fn)))
+		    (if (null? old-fn)
+			new-fn
+			(let ((x1 (car old-fn))
+			      (y1 (cadr old-fn)))
+			  (when (and (< x0 old-att) (>= x1 old-att))
+			    (set! y0 (if (= x1 old-att)
+					 y1
+					 (+ y0 (* (- y1 y0) (/ (- old-att x0) (- x1 x0))))))
+			    (set! x0 old-att)
+			    (set! new-x new-att)
+			    (set! new-fn (cons y0 (cons new-x new-fn)))
+			    (set! scl (if old-dec
+					  (/ (- new-dec new-att) (- old-dec old-att))
+					  (/ (- last-x new-att) (- last-x old-att)))))
+			  (when (and (real? old-dec)
+				     (< x0 old-dec)
+				     (>= x1 old-dec))
+			    (set! y0 (if (= x1 old-dec)
+					 y1
+					 (+ y0 (* (- y1 y0) (/ (- old-dec x0) (- x1 x0))))))
+			    (set! x0 old-dec)
+			    (set! new-x new-dec)
+			    (set! new-fn (cons y0 (cons new-x new-fn)))
+			    (set! scl (/ (- last-x new-dec) (- last-x old-dec))))
+			  (unless (= x0 x1)
+			    (set! new-x (+ new-x (* scl (- x1 x0))))
+			    (set! new-fn (cons y1 (cons new-x new-fn)))
+			    (set! x0 x1)
+			    (set! y0 y1))
+			  (stretch-envelope-1 new-fn (cddr old-fn)))))))))))))
+  
 
 ;;; -------- scale-envelope
 
@@ -281,41 +281,41 @@ inserted between repeats. 'normalized' causes the new envelope's x axis
 to have the same extent as the original's. 'reflected' causes every other 
 repetition to be in reverse."))
     (lambda* (ur-env repeats reflected normalized)
-      (let* ((times (if reflected (floor (/ repeats 2)) repeats))
-	     (e (if (not reflected)
-		    ur-env
-		    (let ((lastx (ur-env (- (length ur-env) 2)))
-			  (rev-env (cddr (reverse ur-env)))
-			  (new-env (reverse ur-env)))
-		      (while (pair? rev-env)
-			     (set! new-env (cons (- (+ lastx lastx) (cadr rev-env)) new-env))
-			     (set! new-env (cons (car rev-env) new-env))
-			     (set! rev-env (cddr rev-env)))
-		      (reverse new-env))))
-	     (first-y (cadr e))
-	     (x-max (e (- (length e) 2)))
-	     (x (car e))
-	     (first-y-is-last-y (= first-y (e (- (length e) 1))))
-	     (new-env (list first-y x)))
-	(let ((len (length e)))
-	  (do ((i 0 (+ i 1)))
-	      ((= i times))
-	    (do ((j 2 (+ j 2)))
-		((>= j len))
-	      (set! x (- (+ x (e j)) (e (- j 2))))
-	      (set! new-env (cons (e (+ j 1)) (cons x new-env))))
-	    (if (and (< i (- times 1)) (not first-y-is-last-y))
-		(begin
-		  (set! x (+ x (/ x-max 100.0)))
-		  (set! new-env (cons first-y (cons x new-env)))))))
-	(set! new-env (reverse new-env))
-	(if normalized
-	    (let ((scl (/ x-max x))
-		  (new-len (length new-env)))
-	      (do ((i 0 (+ i 2)))
-		  ((>= i new-len))
-		(set! (new-env i) (* scl (new-env i))))))
-	new-env))))
+      (let ((e (if (not reflected)
+		   ur-env
+		   (let ((lastx (ur-env (- (length ur-env) 2)))
+			 (rev-env (cddr (reverse ur-env)))
+			 (new-env (reverse ur-env)))
+		     (while (pair? rev-env)
+			    (set! new-env (cons (- (+ lastx lastx) (cadr rev-env)) new-env))
+			    (set! new-env (cons (car rev-env) new-env))
+			    (set! rev-env (cddr rev-env)))
+		     (reverse new-env)))))
+	(let ((first-y (cadr e))
+	      (x (car e)))
+	  (let ((x-max (e (- (length e) 2)))
+		(new-env (list first-y x)))
+	    (let ((len (length e))
+		  (times (if reflected (floor (/ repeats 2)) repeats))
+		  (first-y-is-last-y (= first-y (e (- (length e) 1)))))
+	      (do ((i 0 (+ i 1)))
+		  ((= i times))
+		(do ((j 2 (+ j 2)))
+		    ((>= j len))
+		  (set! x (- (+ x (e j)) (e (- j 2))))
+		  (set! new-env (cons (e (+ j 1)) (cons x new-env))))
+		(if (and (< i (- times 1)) (not first-y-is-last-y))
+		    (begin
+		      (set! x (+ x (/ x-max 100.0)))
+		      (set! new-env (cons first-y (cons x new-env)))))))
+	    (set! new-env (reverse new-env))
+	    (if normalized
+		(let ((scl (/ x-max x))
+		      (new-len (length new-env)))
+		  (do ((i 0 (+ i 2)))
+		      ((>= i new-len))
+		    (set! (new-env i) (* scl (new-env i))))))
+	    new-env))))))
 
 
 ;;; -------- power-env 
@@ -390,30 +390,30 @@ repetition to be in reverse."))
   (let ((documentation "(powenv-channel envelope (beg 0) dur snd chn edpos) returns an envelope with a separate base for \
 each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
     (lambda* (envelope (beg 0) dur snd chn edpos)
-      (let* ((curbeg beg)
-	     (fulldur (or dur (framples snd chn edpos)))
-	     (len (length envelope))
-	     (x1 (car envelope))
-	     (xrange (- (envelope (- len 3)) x1))
-	     (y1 (cadr envelope))
-	     (base (caddr envelope))
-	     (x0 0.0)
-	     (y0 0.0))
-	(if (= len 3)
-	    (scale-channel y1 beg dur snd chn edpos)
-	    (as-one-edit
-	     (lambda ()
-	       (do ((i 3 (+ i 3)))
-		   ((= i len))
-		 (set! x0 x1)
-		 (set! y0 y1)
-		 (set! x1 (envelope i))
-		 (set! y1 (envelope (+ i 1)))
-		 (let ((curdur (round (* fulldur (/ (- x1 x0) xrange)))))
-		   (xramp-channel y0 y1 base curbeg curdur snd chn edpos)
-		   (set! curbeg (+ curbeg curdur)))
-		 (set! base (envelope (+ i 2)))))))))))
-
+      (let ((len (length envelope))
+	    (x1 (car envelope)))
+	(let ((curbeg beg)
+	      (fulldur (or dur (framples snd chn edpos)))
+	      (xrange (- (envelope (- len 3)) x1))
+	      (y1 (cadr envelope))
+	      (base (caddr envelope))
+	      (x0 0.0)
+	      (y0 0.0))
+	  (if (= len 3)
+	      (scale-channel y1 beg dur snd chn edpos)
+	      (as-one-edit
+	       (lambda ()
+		 (do ((i 3 (+ i 3)))
+		     ((= i len))
+		   (set! x0 x1)
+		   (set! y0 y1)
+		   (set! x1 (envelope i))
+		   (set! y1 (envelope (+ i 1)))
+		   (let ((curdur (round (* fulldur (/ (- x1 x0) xrange)))))
+		     (xramp-channel y0 y1 base curbeg curdur snd chn edpos)
+		     (set! curbeg (+ curbeg curdur)))
+		   (set! base (envelope (+ i 2))))))))))))
+  
 
 ;;; by Anders Vinjar:
 ;;;
@@ -429,22 +429,22 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
 (define envelope-exp 
   (let ((documentation "(envelope-exp e (power 1.0) (xgrid 100)) approximates an exponential curve connecting the breakpoints"))
     (lambda* (e (power 1.0) (xgrid 100))
-      (let* ((mn (min-envelope e))
-	     (largest-diff (* 1.0 (- (max-envelope e) mn)))
-	     (x-min (car e))
-	     (x-max (e (- (length e) 2)))
-	     (x-incr (* 1.0 (/ (- x-max x-min) xgrid)))
-	     (new-e ()))
-	(do ((x x-min (+ x x-incr)))
-	    ((>= x x-max))
-	  (let ((y (envelope-interp x e)))
-	    (set! new-e (cons (if (= largest-diff 0.0)
-				  y
-				  (+ mn
-				     (* largest-diff
-					(expt (/ (- y mn) largest-diff) power))))
-			      (cons x new-e)))))
-	(reverse new-e)))))
+      (let ((mn (min-envelope e)))
+	(let ((largest-diff (* 1.0 (- (max-envelope e) mn)))
+	      (x-min (car e))
+	      (x-max (e (- (length e) 2))))
+	  (let ((x-incr (* 1.0 (/ (- x-max x-min) xgrid)))
+		(new-e ()))
+	    (do ((x x-min (+ x x-incr)))
+		((>= x x-max))
+	      (let ((y (envelope-interp x e)))
+		(set! new-e (cons (if (= largest-diff 0.0)
+				      y
+				      (+ mn
+					 (* largest-diff
+					    (expt (/ (- y mn) largest-diff) power))))
+				  (cons x new-e)))))
+	    (reverse new-e)))))))
 
 
 ;;; rms-envelope
@@ -453,39 +453,38 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
   (let ((documentation "(rms-envelope file (beg 0.0) (dur #f) (rfreq 30.0) (db #f)) returns an envelope of RMS values in 'file'"))
     (lambda* (file (beg 0.0) dur (rfreq 30.0) db)
       ;; based on rmsenv.ins by Bret Battey
-      (let* ((e ())
-	     (incr (/ 1.0 rfreq))
-	     (fsr (srate file))
-	     (incrsamps (round (* incr fsr)))
+      (let* ((fsr (srate file))
 	     (start (round (* beg fsr)))
-	     (reader (make-sampler start file))
 	     (end (if dur (min (* 1.0 (+ start (round (* fsr dur))))
 			       (mus-sound-framples file))
-		      (mus-sound-framples file)))
-	     (rms (make-moving-average incrsamps)) ; this could use make-moving-rms from dsp.scm
-	     (rms-val 0.0)
-	     (jend 0)
-	     (len (- (+ end 1) start))
-	     (data (make-float-vector len)))
-	(do ((i 0 (+ i 1)))
-	    ((= i len))
-	  (float-vector-set! data i (next-sample reader)))
-	(float-vector-multiply! data data)
-	(do ((i 0 (+ i incrsamps)))
-	    ((>= i end) 
-	     (reverse e))
-	  (set! jend (min end (+ i incrsamps)))
-	  (do ((j i (+ j 1)))
-	      ((= j jend))
-	    (moving-average rms (float-vector-ref data j)))
-	  (set! e (cons (* 1.0 (/ i fsr)) e))
-	  (set! rms-val (sqrt (* (mus-scaler rms) (mus-increment rms))))
-	  (set! e (cons (if db 
-			    (if (< rms-val 1e-05) -100.0 (* 20.0 (log rms-val 10.0)))
-			    rms-val)
-			e)))))))
-
-
+		      (mus-sound-framples file))))
+	(let ((incrsamps (round (/ fsr rfreq)))
+	      (len (- (+ end 1) start)))
+	  (let ((reader (make-sampler start file))
+		(rms (make-moving-average incrsamps)) ; this could use make-moving-rms from dsp.scm
+		(e ())
+		(rms-val 0.0)
+		(jend 0)
+		(data (make-float-vector len)))
+	    (do ((i 0 (+ i 1)))
+		((= i len))
+	      (float-vector-set! data i (next-sample reader)))
+	    (float-vector-multiply! data data)
+	    (do ((i 0 (+ i incrsamps)))
+		((>= i end) 
+		 (reverse e))
+	      (set! jend (min end (+ i incrsamps)))
+	      (do ((j i (+ j 1)))
+		  ((= j jend))
+		(moving-average rms (float-vector-ref data j)))
+	      (set! e (cons (* 1.0 (/ i fsr)) e))
+	      (set! rms-val (sqrt (* (mus-scaler rms) (mus-increment rms))))
+	      (set! e (cons (if db 
+				(if (< rms-val 1e-05) -100.0 (* 20.0 (log rms-val 10.0)))
+				rms-val)
+			    e)))))))))
+  
+  
 (define* (normalize-envelope env1 (new-max 1.0))
   (scale-envelope env1
 		  (/ new-max
