@@ -183,17 +183,17 @@ amp: (play-with-amps 0 1.0 0.5) plays channel 2 of stereo sound at half amplitud
 (define play-sines 
   (let ((documentation "(play-sines freqs-and-amps) produces a tone given its spectrum: (play-sines '((440 .4) (660 .3)))"))
     (lambda (freqs-and-amps)
-      (let* ((len 44100)
-	     (num-oscs (length freqs-and-amps))
-	     (frqs (make-float-vector num-oscs))
-	     (amps (make-float-vector num-oscs)))
-	(do ((i 0 (+ i 1)))
-	    ((= i num-oscs))
-	  (set! (frqs i) (hz->radians (car (freqs-and-amps i))))
-	  (set! (amps i) (cadr (freqs-and-amps i))))
-	(let ((ob (make-oscil-bank frqs (make-float-vector num-oscs) amps #t)))
-	  (play (lambda ()
-		  (and (positive? (set! len (- len 1)))
-		       (oscil-bank ob)))))))))
+      (let ((num-oscs (length freqs-and-amps)))
+	(let ((len 44100)
+	      (frqs (make-float-vector num-oscs))
+	      (amps (make-float-vector num-oscs)))
+	  (do ((i 0 (+ i 1)))
+	      ((= i num-oscs))
+	    (set! (frqs i) (hz->radians (car (freqs-and-amps i))))
+	    (set! (amps i) (cadr (freqs-and-amps i))))
+	  (let ((ob (make-oscil-bank frqs (make-float-vector num-oscs) amps #t)))
+	    (play (lambda ()
+		    (and (positive? (set! len (- len 1)))
+			 (oscil-bank ob))))))))))
 
 ;; (play-sines '((425 .05) (450 .01) (470 .01) (546 .02) (667 .01) (789 .034) (910 .032)))
