@@ -110,12 +110,11 @@
 	  (define history (dilambda 
 			   (lambda (back)
 			     (let ((i (+ histpos back)))
-			       (copy (if (< i 0)
-					 (histbuf (+ histsize i))
-					 (if (>= i histsize)
-					     (histbuf (- i histsize))
-					     (histbuf i))))))
-
+			       (copy (histbuf (if (< i 0)
+						  (+ histsize i)
+						  (if (>= i histsize)
+						      (- i histsize)
+						      i))))))
 			   (lambda (new-line)
 			     (let ((pos (history-member new-line)))
 			       (when (integer? pos)                   ; remove the earlier case, circularly compress the buffer
@@ -346,12 +345,12 @@
 		    (do ((i 0 (+ i 1)))
 			((= i new-red))
 		      (set! col (if (char=? (cur-line i) #\newline) 0 (+ col 1))))
-		    (let* ((sym (do ((i (+ new-red 1) (+ i 1)))
-				    ((not (char-alphabetic? (cur-line i)))
-				     (substring cur-line (+ new-red 1) i))))
-			   (spaces (+ col (if (member sym '("or" "and" "cond" "if"))
-					      (+ (length sym) 2)
-					      2))))
+		    (let ((spaces (let ((sym (do ((i (+ new-red 1) (+ i 1)))
+						 ((not (char-alphabetic? (cur-line i)))
+						  (substring cur-line (+ new-red 1) i)))))
+				    (+ col (if (member sym '("or" "and" "cond" "if"))
+					       (+ (length sym) 2)
+					       2)))))
 		      (if (= cursor-pos (length cur-line))
 			  (begin
 			    (set! cur-line (format #f "~A~NC" cur-line spaces #\space))
