@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "4.6"
-#define S7_DATE "20-Feb-16"
+#define S7_VERSION "4.8"
+#define S7_DATE "30-May-16"
 
 typedef long long int s7_int; /* This sets the size of integers in Scheme; it needs to be big enough to accomodate a C pointer. */
 typedef double s7_double;     /*   similarly for Scheme reals; only "double" works in C++ */
@@ -775,6 +775,8 @@ s7_pointer s7_apply_n_9(s7_scheme *sc, s7_pointer args,
  * 
  *        s7 changes
  *
+ * 30-May:    symbol takes any number of args.  make-vector no longer takes an optional fourth argument.
+ * 24-May:    let-ref/set! check rootlet now if let is not an open let; setter for with-let.
  * 20-Feb:    removed last vestiges of quasiquoted vector support.
  * 3-Feb:     *cload-directory*.
  * 14-Jan:    profile.scm. Moved multiple-value-set! to stuff.scm. Setter for port-line-number.
