@@ -42,18 +42,17 @@
 			   (return (list snd chn))))
 		     (car scs)
 		     (cadr scs))))))))
-	(if (selection?)
-	    (if (= (selection-chans) 2)
-		(let* ((beg (selection-position))
-		       (len (selection-framples))
-		       (snd-chn0 (find-selection-sound ()))
+	(if (not (selection?))
+	    (error 'no-active-selection "swap-selection-channels needs a selection")
+	    (if (not (= (selection-chans) 2))
+		(error 'wrong-number-of-channels "swap-selection-channels needs a stereo selection")
+		(let* ((snd-chn0 (find-selection-sound ()))
 		       (snd-chn1 (find-selection-sound snd-chn0)))
-		  (if snd-chn1
-		      (swap-channels (car snd-chn0) (cadr snd-chn0) (car snd-chn1) (cadr snd-chn1) beg len)
-		      (error 'wrong-number-of-channels "swap-selection-channels needs two channels to swap")))
-		(error 'wrong-number-of-channels "swap-selection-channels needs a stereo selection"))
-	    (error 'no-active-selection "swap-selection-channels needs a selection"))))))
-
+		  (let ((beg (selection-position))
+			(len (selection-framples)))
+		    (if snd-chn1
+			(swap-channels (car snd-chn0) (cadr snd-chn0) (car snd-chn1) (cadr snd-chn1) beg len)
+			(error 'wrong-number-of-channels "swap-selection-channels needs two channels to swap"))))))))))
 
 
 ;;; -------- replace-with-selection
