@@ -61,7 +61,7 @@
   
   (define (display-scanned-synthesis)
     
-    (define compute-uniform-circular-string
+    (define vibrating-uniform-circular-string
       ;; copied from dsp.scm to simplify life
       (lambda (size x0 x1 x2 mass xspring damp)
 	(define circle-float-vector-ref 
@@ -193,7 +193,7 @@
       
       (define (tick-synthesis n)
 	;; background process
-	(compute-uniform-circular-string size gx0 gx1 gx2 mass xspring damp)
+	(vibrating-uniform-circular-string size gx0 gx1 gx2 mass xspring damp)
 	(let* ((wn (GDK_WINDOW (gtk_widget_get_window scan-pane)))
 	       (cr (gdk_cairo_create wn)))
 	  (draw-graph cr)
@@ -762,26 +762,25 @@
   (define variables-pages ())
   
   (define (make-variables-dialog)
-    (let ((dismiss-button #f))
-      (set! variables-dialog (gtk_dialog_new))
-      (gtk_window_set_title (GTK_WINDOW variables-dialog) "Variables")
-      (gtk_container_set_border_width (GTK_CONTAINER variables-dialog) 10)
-      (gtk_window_set_default_size (GTK_WINDOW variables-dialog) -1 -1)
-      (gtk_window_set_resizable (GTK_WINDOW variables-dialog) #t)
-      (gtk_widget_realize variables-dialog)
-      (g_signal_connect variables-dialog "delete_event" (lambda (w ev data) (gtk_widget_hide variables-dialog) #t) #f)
+    (set! variables-dialog (gtk_dialog_new))
+    (gtk_window_set_title (GTK_WINDOW variables-dialog) "Variables")
+    (gtk_container_set_border_width (GTK_CONTAINER variables-dialog) 10)
+    (gtk_window_set_default_size (GTK_WINDOW variables-dialog) -1 -1)
+    (gtk_window_set_resizable (GTK_WINDOW variables-dialog) #t)
+    (gtk_widget_realize variables-dialog)
+    (g_signal_connect variables-dialog "delete_event" (lambda (w ev data) (gtk_widget_hide variables-dialog) #t) #f)
       
-      (set! dismiss-button (gtk_dialog_add_button (GTK_DIALOG variables-dialog) "Go Away" GTK_RESPONSE_NONE))
+    (let ((dismiss-button (gtk_dialog_add_button (GTK_DIALOG variables-dialog) "Go Away" GTK_RESPONSE_NONE)))
       (g_signal_connect dismiss-button "clicked" (lambda (w data) (gtk_widget_hide variables-dialog)) #f)
       (gtk_widget_show dismiss-button)
-      (gtk_widget_set_name dismiss-button "quit_button")
+      (gtk_widget_set_name dismiss-button "quit_button"))
       
-      (set! variables-notebook (gtk_notebook_new))
-      (gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG variables-dialog))) variables-notebook #t #t 4)
-      (gtk_notebook_set_tab_pos (GTK_NOTEBOOK variables-notebook) GTK_POS_RIGHT)
-      (gtk_widget_show variables-notebook)
-      (gtk_widget_show variables-dialog)
-      variables-dialog))
+    (set! variables-notebook (gtk_notebook_new))
+    (gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG variables-dialog))) variables-notebook #t #t 4)
+    (gtk_notebook_set_tab_pos (GTK_NOTEBOOK variables-notebook) GTK_POS_RIGHT)
+    (gtk_widget_show variables-notebook)
+    (gtk_widget_show variables-dialog)
+    variables-dialog)
   
   (define* (make-variable-display page-name variable-name (type 'text) (range (list 0.0 1.0)))
     ;; type = 'text, 'meter, 'graph, 'spectrum, 'scale
@@ -851,27 +850,26 @@
 	      (gtk_label_set_text (GTK_LABEL widget) (object->string var))
 	      (force-update widget)))
 	
-	(if (pair? widget)
-	    (if (or (number? (car widget))
-		    (sound? (car widget)))
-		;; graph/spectrum -- does this need an explicit update?
-		(let* ((snd (car widget))
-		       (data (cadr widget))
-		       (len (length data))
-		       (loc (cursor snd 0)))
-		  (set! (data loc) var)
-		  (if (time-graph? snd) (update-time-graph snd))
-		  (if (transform-graph? snd) (update-transform-graph snd))
-		  (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
-		(if (GTK_IS_PROGRESS_BAR (car widget))
-		    ;; "thermometer"
-		    (let ((y0 (cadr widget))
-			  (y1 (caddr widget)))
-		      ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
-		      (gtk_progress_bar_set_fraction 
-		       (GTK_PROGRESS_BAR (car widget))
-		       (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))
-		    ))))
+	(when (and (pair? widget)
+		   (or (number? (car widget))
+		       (sound? (car widget))))
+	  ;; graph/spectrum -- does this need an explicit update?
+	  (let ((snd (car widget))
+		(data (cadr widget)))
+	    (let ((len (length data))
+		  (loc (cursor snd 0)))
+	      (set! (data loc) var)
+	      (if (time-graph? snd) (update-time-graph snd))
+	      (if (transform-graph? snd) (update-transform-graph snd))
+	      (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
+	    (if (GTK_IS_PROGRESS_BAR (car widget))
+		;; "thermometer"
+		(let ((y0 (cadr widget))
+		      (y1 (caddr widget)))
+		  ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
+		  (gtk_progress_bar_set_fraction 
+		   (GTK_PROGRESS_BAR (car widget))
+		   (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))))))
     var)
 
   (define (notebook-with-top-tabs)
