@@ -360,9 +360,9 @@
 	    (break))))))
 
 (define-macro (do* spec end . body)
-  `(let* (,@(map (lambda (var) 
-		   (list (car var) (cadr var))) 
-		 spec))
+  `(let* ,(map (lambda (var) 
+		 (list (car var) (cadr var))) 
+	       spec)
      (do () ,end
        ,@body
        ,@(map (lambda (var) 
@@ -581,31 +581,31 @@ If func approves of one, index-if returns the index that gives that element's po
        (if (not (pair? p))
 	   (make-iterator p)
 	   (let ((len (length p)))
-	     (if (infinite? len)      ; circular list
-		 (make-iterator
-		  (let ((cur p)
-			(iterator? #t))
-		    (lambda ()
-		      (if (memq cur seen-cycles)
-			  #<eof>
-			  (let ((result (car cur)))
-			    (if (memq cur cycles) 
-				(set! seen-cycles (cons cur seen-cycles)))
-			    (set! cur (cdr cur))
-			    result)))))
-		 (if (positive? len)  ; normal list
-		     (make-iterator p)
-		     (make-iterator   ; dotted list
-		      (let ((cur p)
-			    (iterator? #t))
-			(lambda ()
-			  (if (pair? cur)
-			      (let ((result (car cur)))
-				(set! cur (cdr cur))
-				result)
-			      (let ((result cur))
-				(set! cur #<eof>)
-				result))))))))))
+	     (make-iterator
+	      (cond ((infinite? len)      ; circular list
+		     (let ((cur p)
+			   (iterator? #t))
+		       (lambda ()
+			 (if (memq cur seen-cycles)
+			     #<eof>
+			     (let ((result (car cur)))
+			       (if (memq cur cycles) 
+				   (set! seen-cycles (cons cur seen-cycles)))
+			       (set! cur (cdr cur))
+			       result)))))
+		    ((positive? len)      ; normal list
+		     p)
+		    (else 
+		     (let ((cur p)        ; dotted list
+			   (iterator? #t))
+		       (lambda ()
+			 (if (pair? cur)
+			     (let ((result (car cur)))
+			       (set! cur (cdr cur))
+			       result)
+			     (let ((result cur))
+			       (set! cur #<eof>)
+			       result))))))))))
 
      (let ((iter (make-careful-iterator obj))
 	   (iterator? #t))       
@@ -1043,8 +1043,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   ;; for arbitrary method combinations: this returns a list of all the methods of a given name
   ;;   in obj's class and the classes it inherits from (see example below)
   (if (symbol? method)
-      (let* ((base-method (obj method))
-	     (methods (if (procedure? base-method) (list base-method) ())))
+      (let ((methods (let ((base-method (obj method)))
+		       (if (procedure? base-method) (list base-method) ()))))
 	(for-each 
 	 (lambda (ancestor)
 	   (let ((next-method (ancestor method)))
@@ -1280,12 +1280,12 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		  (if (symbol? sym)
 		      `(set! (symbol-access ',sym)
 			     (lambda (s v)  
-			       (let ((,nv ,(if (with-let (sublet e 'sym sym) 
-						 (symbol-access sym))
+			       (let ((,nv ,(if (not (with-let (sublet e 'sym sym) 
+						      (symbol-access sym)))
+					       'v
 					       `(begin (,(procedure-source (with-let (sublet e 'sym sym) 
 									     (symbol-access sym))) 
-							s v))
-					       'v)))
+							s v)))))
 				 (with-let (sublet ,ne ',sym ,nv)
 				   (set! ,place ,value))
 				 ,nv)))
@@ -1419,8 +1419,10 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		    (set! setters (cons sym setters)))
 		(let ((prev (assq sym accessors)))
 		  (if prev
-		      (set-cdr! prev (append `((set! ,(car bd) (,fname ,v))) (cdr prev)))
-		      (set! accessors (cons (cons sym `((set! ,(car bd) (,fname ,v)))) accessors))))))
+		      (set-cdr! prev (cons (list 'set! (car bd) (list fname v)) (cdr prev)))
+		      (set! accessors (cons (list sym (list 'set! (car bd) (list fname v))) accessors))))))
+		      ;; (append `((set! ,(car bd) (,fname ,v))) (cdr prev)))
+		      ;; (set! accessors (cons (cons sym `((set! ,(car bd) (,fname ,v)))) accessors))))))
 	    syms)
 	   (set! bindings (cons bd bindings))))
        vars)
@@ -1633,8 +1635,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 
 (define* (subsequence obj (start 0) end)
-  (let* ((len (length obj))
-	 (new-len (- (min len (or end len)) start)))
+  (let ((new-len (let ((len (length obj)))
+		   (- (min len (or end len)) start))))
     (if (negative? new-len)
 	(error 'out-of-range "end: ~A should be greater than start: ~A" end start))
 
@@ -1760,8 +1762,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
       (set! (*s7* 'print-length) vlp)))
   
   (define (last lst)
-    (let* ((len (length lst))
-	   (end (list-tail lst (if (negative? len) (abs len) (- len 1)))))
+    (let ((end (let ((len (length lst)))
+		 (list-tail lst (if (negative? len) (abs len) (- len 1))))))
       (if (pair? end)
 	  (car end)
 	  end)))
@@ -1946,9 +1948,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	  
 	  ((dynamic-wind)
 	   ;; here we want to ignore the first and last clauses, and report the last of the second
-	   (let* ((p (caddr source))
-		  (body (and (eq? (car p) 'lambda)
-			     (cddr p)))
+	   (let* ((body (let ((p (caddr source)))
+			  (and (eq? (car p) 'lambda)
+			       (cddr p))))
 		  (previous (and body (butlast body)))
 		  (end (and body (last body))))
 	     (if (not body)
