@@ -229,66 +229,61 @@
 	(else
 	 (let* ((len (length scheme-name))
 		(var-case (hash-table-ref scheme-variable-names scheme-name))
-		(strlen (if var-case (+ len 1) len))
-		(rb-name (make-string strlen #\space))
-		(i 0)
-		(j 0))
-	   (if var-case
-	       (begin
-		 (set! (rb-name 0) #\$)
-		 (set! j 1))
-	       (if (hash-table-ref scheme-constant-names scheme-name)
-		   (begin
-		     (set! (rb-name 0) (char-upcase (scheme-name 0)))
-		     (set! i 1)
-		     (set! j 1))))
-	   (do ()
-	       ((>= i len))
-	     (let ((c (scheme-name i)))
-	       (if (or (alphanumeric? c)
-		       (memv c '(#\? #\!)))
-		   (begin
-		     (set! (rb-name j) c)
-		     (set! i (+ i 1))
-		     (set! j (+ j 1)))
-		   (if (and (char=? c #\-)
-			    (char=? (scheme-name (+ i 1)) #\>))
-		       (begin
-			 (set! (rb-name j) #\2)
-			 (set! j (+ j 1))
-			 (set! i (+ i 2)))
-		       (begin
-			 (set! (rb-name j) #\_)
-			 (set! i (+ i 1))
-			 (set! j (+ j 1)))))))
-	   (if (= j strlen)
-	       rb-name
-	       (substring rb-name 0 j))))))
+		(strlen (if var-case (+ len 1) len)))
+	   (let ((rb-name (make-string strlen #\space))
+		 (i 0)
+		 (j 0))
+	     (if var-case
+		 (begin
+		   (set! (rb-name 0) #\$)
+		   (set! j 1))
+		 (if (hash-table-ref scheme-constant-names scheme-name)
+		     (begin
+		       (set! (rb-name 0) (char-upcase (scheme-name 0)))
+		       (set! i 1)
+		       (set! j 1))))
+	     (do ()
+		 ((>= i len))
+	       (let ((c (scheme-name i)))
+		 (if (or (alphanumeric? c)
+			 (memv c '(#\? #\!)))
+		     (begin
+		       (set! (rb-name j) c)
+		       (set! i (+ i 1))
+		       (set! j (+ j 1)))
+		     (if (and (char=? c #\-)
+			      (char=? (scheme-name (+ i 1)) #\>))
+			 (begin
+			   (set! (rb-name j) #\2)
+			   (set! j (+ j 1))
+			   (set! i (+ i 2)))
+			 (begin
+			   (set! (rb-name j) #\_)
+			   (set! i (+ i 1))
+			   (set! j (+ j 1)))))))
+	     (if (= j strlen)
+		 rb-name
+		 (substring rb-name 0 j)))))))
 
 (define (clean-up-xref xref file)
   (let* ((len (length xref))
 	 (outstr (make-string (* len 2) #\space)))
     (let ((url-str "")
-	  (j 0)
-	  (need-start #f)
-	  (in-bracket #f)
-	  (in-href #f)
-	  (in-name #f))
+	  (j 0))
       (do ((loc 0))
 	  ((>= loc len))
-	(let* ((leof (or (char-position #\newline xref loc)
-			 len))
-	       (href-normal-start (or (string-position "<a href=" xref loc)
-				      (string-position "<A HREF=" xref loc)))
-	       (href-start (or href-normal-start 
-			       (string-position "<a class=quiet href=" xref loc)
-			       (string-position "<a class=def href=" xref loc)))
-	       (href-len (if href-normal-start 8 20))
-	       (href-end (and (integer? href-start)
-			      (< href-start leof)
-			      (char-position #\> xref (+ href-start 1))))
-	       (href (and (integer? href-end)
-			  (substring xref (+ href-start href-len) href-end))))
+	(let* ((leof (or (char-position #\newline xref loc) len))	    
+	       (href (let* ((href-normal-start (or (string-position "<a href=" xref loc)
+						   (string-position "<A HREF=" xref loc)))
+			    (href-start (or href-normal-start 
+					    (string-position "<a class=quiet href=" xref loc)
+					    (string-position "<a class=def href=" xref loc))))
+		       (let ((href-len (if href-normal-start 8 20))
+			     (href-end (and (integer? href-start)
+					    (< href-start leof)
+					    (char-position #\> xref (+ href-start 1)))))
+			 (and (integer? href-end)
+			      (substring xref (+ href-start href-len) href-end))))))
 	  (set! url-str (string-append url-str
 				       (if href
 					   (if (char=? (href 1) #\#)
@@ -299,7 +294,11 @@
 
       (set! (outstr j) #\")
       (set! j (+ j 1))
-      (do ((i 0 (+ i 1)))
+      (do ((need-start #f)
+	   (in-bracket #f)
+	   (in-href #f)
+	   (in-name #f)
+	   (i 0 (+ i 1)))
 	  ((= i len))
 	(let ((c (xref i)))
 	  (if in-bracket
@@ -840,9 +839,9 @@
   ;; alternate: (autoload sym (lambda (e) (let ((m (load file))) (varlet (rootlet) (cons sym (m sym))))))
   (for-each
    (lambda (sym&file)
-     (let* ((e (car sym&file))
-	    (file (cadr sym&file))
-	    (ce (if (not (defined? e)) (load file) (symbol->value e)))
+     (let* ((file (cadr sym&file))
+	    (ce (let ((e (car sym&file)))
+		  (if (not (defined? e)) (load file) (symbol->value e))))
 	    (flst (or (hash-table-ref names file) ())))
        (for-each
 	(lambda (slot)
@@ -933,86 +932,83 @@
 	      (let* ((dline line)
 		     (compos (string-position "<!-- INDEX" dline))
 		     (indpos (string-position "<!-- main-index" dline))
-		     (xpos (string-position "<TABLE " dline))
-		     (unxpos (string-position "</TABLE>" dline))
 		     (pos (and (not compos) 
 			       (not indpos)
-			       (string-position "<em class=def id=" dline)
-			       ))
-		     (id-pos (string-position " id=" dline))
-		     (tpos (and (not pos) 
-				(string-position "<!-- TOPIC " line))))
-		(if unxpos 
-		    (set! xrefing #f))
+			       (string-position "<em class=def id=" dline))))
+		(let ((xpos (string-position "<TABLE " dline))
+		      (tpos (and (not pos) 
+				 (string-position "<!-- TOPIC " line))))
+		  (if (string-position "</TABLE>" dline)
+		      (set! xrefing #f))
+		  
+		  (let ((id-pos (string-position " id=" dline)))
+		    (if id-pos
+			(let ((sym-name (let ((start (- (char-position #\" dline id-pos) id-pos)))
+					  (string->symbol
+					   (substring dline 
+						      (+ id-pos start 1)
+						      (let ((end-start (+ id-pos start 2)))	   
+							(- (+ id-pos start (char-position #\" dline end-start) 2) end-start)))))))
+			  (if (not (hash-table-ref ids sym-name))
+			      (hash-table-set! ids sym-name 0)
+			      (if (memq sym-name local-ids)
+				  (format () "~S: id ~S is set twice~%" file sym-name)))
+			  (set! local-ids (cons sym-name local-ids)))))
 		
-		(if id-pos
-		    (let* ((start (- (char-position #\" dline id-pos) id-pos)) ; (substring dline id-pos)))
-			   (end-start (+ id-pos start 2))
-			   (name (substring dline 
-					    (+ id-pos start 1)
-					    (- (+ id-pos start (char-position #\" dline end-start) 2) end-start)))
-			   (sym-name (string->symbol name)))
-		      (if (not (hash-table-ref ids sym-name))
-			  (hash-table-set! ids sym-name 0)
-			  (if (memq sym-name local-ids)
-			      (format () "~S: id ~S is set twice~%" file sym-name)))
-		      (set! local-ids (cons sym-name local-ids))))
-		
-		(cond (tpos
-		       (let ((epos (string-position " -->" dline)))
-			 (if (not epos) 
-			     (format () "<!-- TOPIC but no --> for ~A~%" dline)
-			     (set! topic (substring dline (+ tpos 11) epos)))))
-		      (compos
-		       (let ((epos (string-position " -->" dline)))
-			 (if (not epos) 
-			     (format () "<!-- INDEX but no --> for ~A~%" dline)
-			     (when (or (not no-bold)
-				       with-scm)
-			       (set! current-general g)
-			       (set! (generals g) (substring dline (+ compos 11) epos))
-			       (set! (gfiles g) (car file))
-			       (set! (xrefs g) "")
-			       (set! g (+ g 1))))))
-		      (indpos
-		       (let ((epos (string-position " -->" dline)))
-			 (if (not epos) 
-			     (format () "<!-- main-index but no --> for ~A~%" dline)
-			     (when (or (not no-bold)
-				       with-scm)
-			       (set! (names n) (substring dline (+ indpos 16) epos))
-			       (set! (files n) (car file))
-			       (set! n (+ n 1))))))
-		      (xpos
-		       (set! xrefing #t))
-		      (else
-		       (do ()
-			   ((not pos))
-			 (set! dline (substring dline pos))
-			 (let ((epos (or (string-position "</a>" dline) 
-					 (string-position "</em>" dline) 
-					 (string-position "</A>" dline))))
+		  (cond (tpos
+			 (let ((epos (string-position " -->" dline)))
 			   (if (not epos) 
-			       (format () "<a> but no </a> for ~A~%" dline)
-			       (begin
-				 (set! (names n) (string-append (substring dline 0 epos) "</a>"))
+			       (format () "<!-- TOPIC but no --> for ~A~%" dline)
+			       (set! topic (substring dline (+ tpos 11) epos)))))
+			(compos
+			 (let ((epos (string-position " -->" dline)))
+			   (if (not epos) 
+			       (format () "<!-- INDEX but no --> for ~A~%" dline)
+			       (when (or (not no-bold)
+					 with-scm)
+				 (set! current-general g)
+				 (set! (generals g) (substring dline (+ compos 11) epos))
+				 (set! (gfiles g) (car file))
+				 (set! (xrefs g) "")
+				 (set! g (+ g 1))))))
+			(indpos
+			 (let ((epos (string-position " -->" dline)))
+			   (if (not epos) 
+			       (format () "<!-- main-index but no --> for ~A~%" dline)
+			       (when (or (not no-bold)
+					 with-scm)
+				 (set! (names n) (substring dline (+ indpos 16) epos))
 				 (set! (files n) (car file))
-				 (set! (topics n) topic)
-				 (set! n (+ n 1))
-				 (set! dline (substring dline (+ epos 4)))
-				 (set! pos (string-position "<em class=def id=" dline))
-				 ))))))
-		(if (and xrefing
-			 (or (not (char=? (dline 0) #\<))
-			     (string-position "<a href" dline)
-			     (string-position "<a class=quiet href" dline)
-			     (string-position "<a class=def href" dline)))
-		    (set! (xrefs current-general) (string-append (xrefs current-general) dline (format #f "~%"))))
-		(when topic
-		  (let ((hpos (string-position "<hr>" dline)))
-		    (when hpos 
-		      (set! topic #f))))))))))
-    ;; end call-with-input-file loop
+				 (set! n (+ n 1))))))
+			(xpos
+			 (set! xrefing #t))
+			(else
+			 (do ()
+			     ((not pos))
+			   (set! dline (substring dline pos))
+			   (let ((epos (or (string-position "</a>" dline) 
+					   (string-position "</em>" dline) 
+					   (string-position "</A>" dline))))
+			     (if (not epos) 
+				 (format () "<a> but no </a> for ~A~%" dline)
+				 (begin
+				   (set! (names n) (string-append (substring dline 0 epos) "</a>"))
+				   (set! (files n) (car file))
+				   (set! (topics n) topic)
+				   (set! n (+ n 1))
+				   (set! dline (substring dline (+ epos 4)))
+				   (set! pos (string-position "<em class=def id=" dline))))))))
+		  (if (and xrefing
+			   (or (not (char=? (dline 0) #\<))
+			       (string-position "<a href" dline)
+			       (string-position "<a class=quiet href" dline)
+			       (string-position "<a class=def href" dline)))
+		      (set! (xrefs current-general) (string-append (xrefs current-general) dline (format #f "~%"))))
+		  (when topic
+		    (let ((hpos (string-position "<hr>" dline)))
+		      (when hpos 
+			(set! topic #f)))))))))))
+      ;; end call-with-input-file loop
 
     (let ((tnames (make-vector (+ n g)))
 	  (ctr 0))
@@ -1189,16 +1185,16 @@
 			 (ind-sortby (tnames i)))
 		    (let* ((line (substring (ind-name (tnames i)) 8))
 			   (dpos (char-position #\> line))
-			   (url (substring line 1 (- dpos 1)))
-			   (ind (substring line (+ dpos 1) (char-position #\< line)))
-			   (gpos (string-position "&gt;" ind)))
-		      (if gpos 
-			  (set! ind (string-append (substring ind 0 gpos) 
-						   ">" 
-						   (substring ind (+ gpos 4)))))
-		      (when (positive? (length ind))
-			(set! help-names (cons ind help-names))
-			(set! help-urls (cons url help-urls))))))
+			   (ind (substring line (+ dpos 1) (char-position #\< line))))
+		      (let ((url (substring line 1 (- dpos 1)))
+			    (gpos (string-position "&gt;" ind)))
+			(if gpos 
+			    (set! ind (string-append (substring ind 0 gpos) 
+						     ">" 
+						     (substring ind (+ gpos 4)))))
+			(when (positive? (length ind))
+			  (set! help-names (cons ind help-names))
+			  (set! help-urls (cons url help-urls)))))))
 	      
 	      (set! help-names (reverse help-names))
 	      (set! help-urls (reverse help-urls))
@@ -1264,7 +1260,14 @@
 (define (html-check files)
   (let ((name 0)
 	(href 0)
-	(names (make-hash-table 2048)))
+	(names (make-hash-table 2048))
+	(closables (let ((h (make-hash-table)))
+		     (for-each (lambda (c)
+				 (set! (h c) #t))
+			       '(ul tr td table small sub blockquote p details summary
+				 a A i b title pre span h1 h2 h3 code body html
+				 em head h4 sup map smaller bigger th tbody div))
+		     h)))
     (for-each
      (lambda (file)
        (call-with-input-file file
@@ -1395,16 +1398,19 @@
 				      (if (eq? closer 'TABLE) (set! closer 'table))
 				      (cond ((memq closer '(center big font))
 					     (format () "~A[~D]: ~A is obsolete, ~A~%" file linectr closer line))
+
 					    ((eq? closer 'script)
 					     (set! scripting #f))
+
 					    (scripting)
+
 					    ((not (memq closer commands))
 					     (format () "~A[~D]: ~A without start? ~A from [~D:~D] (commands: ~A)~%" 
 						     file linectr closer line (+ start 2) i commands))
-					    ((not (memq closer '(ul tr td table small sub blockquote p details summary
-								 a A i b title pre span h1 h2 h3 code body html
-								 em head h4 sup map smaller bigger th tbody div)))
+
+					    ((not (hash-table-ref closables closer))
 					     (set! commands (remove-all closer commands)))
+
 					    (else 
 					     (if (not (eq? (car commands) closer))
 						 (format () "~A[~D]: ~A -> ~A?~%" file linectr closer commands))
@@ -1456,20 +1462,19 @@
 					       (set! scripting #t))
 					      
 					      ((eq? opener 'img)
-					       (let* ((rest-line (substring line (+ start 4)))
-						      (alt-pos (string-position "alt=" rest-line))
-						      (src-pos (string-position "src=" rest-line)))
-						 (if (not alt-pos)
-						     (format () "~A[~D]: img but no alt: ~A~%" file linectr line))
-						 (if src-pos
-						     (let ((png-pos (string-position ".png" rest-line)))
-						       (if png-pos
-							   (let ((file (substring rest-line (+ src-pos 5) (+ png-pos 4))))
-							     (if (not (file-exists? file))
-								 (format () "~A[~D]: src not found: ~S~%" file linectr file))))))))
+					       (let ((rest-line (substring line (+ start 4))))
+						 (let ((alt-pos (string-position "alt=" rest-line))
+						       (src-pos (string-position "src=" rest-line)))
+						   (if (not alt-pos)
+						       (format () "~A[~D]: img but no alt: ~A~%" file linectr line))
+						   (if src-pos
+						       (let ((png-pos (string-position ".png" rest-line)))
+							 (if png-pos
+							     (let ((file (substring rest-line (+ src-pos 5) (+ png-pos 4))))
+							       (if (not (file-exists? file))
+								   (format () "~A[~D]: src not found: ~S~%" file linectr file)))))))))
 					      
-					      ((and (not (memq opener '(br spacer li hr area 
-									   ul tr td table small sub blockquote)))
+					      ((and (not (memq opener '(br spacer li hr area ul tr td table small sub blockquote)))
 						    (memq opener commands)
 						    (= p-quotes 0))
 					       (format () "~A[~D]: nested ~A? ~A from: ~A~%" file linectr opener line commands))
@@ -1532,11 +1537,9 @@
 		     ) ; if not in-comment...
 		   
 		   ;; search for name
-		   (let* ((dline line)
-			  (pos (string-position "<em class=def id=" dline))
+		   (let ((dline line))
+		     (do ((pos (string-position "<em class=def id=" dline))
 			  (pos-len 18))
-		     
-		     (do ()
 			 ((not pos))
 		       (set! dline (substring dline (+ pos pos-len)))
 		       (let ((epos (or (string-position "</a>" dline) 
@@ -1561,12 +1564,11 @@
 			       (set! dline (substring dline epos))
 			       (set! pos (string-position "<em class=def id=" dline))
 			       (set! pos-len 18))))))
-		   
+		     
 		   ;; search for href
-		   (let* ((dline line)
-			  (pos (string-position " href=" dline)) ; ignore A HREF
+		   (let ((dline line))
+		     (do ((pos (string-position " href=" dline)) ; ignore A HREF
 			  (pos-len 7))
-		     (do ()
 			 ((not pos))
 		       ;; (format () "~A dline: ~A~%" pos dline)
 		       (if (zero? (length dline)) (exit))
@@ -1591,9 +1593,9 @@
 				 
 				 ;; cur-href here is the full link: sndclm.html#make-filetosample for example
 				 ;;   it can also be a bare file name
-				 (let* ((start (char-position #\# cur-href))
-					(name (and (number? start) 
-						   (string->symbol (substring cur-href (+ start 1)))))
+				 (let* ((name (let ((start (char-position #\# cur-href)))
+						(and (number? start) 
+						     (string->symbol (substring cur-href (+ start 1))))))
 					(data (and (symbol? name) 
 						   (hash-table-ref ids name))))
 				   (if name 
@@ -1603,8 +1605,7 @@
 			       (set! href (+ href 1))
 			       (set! dline (substring dline epos))
 			       (set! pos (string-position " href=" dline))
-			       (set! pos-len 7))))))))
-	       )
+			       (set! pos-len 7)))))))))
 	     (if (pair? commands) 
 		 (format () "open directives at end of ~A: ~A~%" file commands))))))
      files)
