@@ -209,8 +209,8 @@
       (set! vecs (cons (make-vector size i) vecs))
       (set! ivecs (cons (make-int-vector size i) ivecs))
       (set! fvecs (cons (make-float-vector size (* i 1.0)) fvecs))
-      (set! ifvecs (cons (make-vector size (if (even? i) (* i 1.0) i) #t) ifvecs))
-      (set! allvecs (cons (make-vector size (if (even? i) (* i 1.0) i) (not (zero? (modulo i 3)))) allvecs))
+      (set! ifvecs (cons ((if (even? i) make-float-vector make-int-vector) size (if (even? i) (* i 1.0) i)) ifvecs))
+      (set! allvecs (cons (make-vector size (if (even? i) (* i 1.0) i)) allvecs))
       (set! lsts (cons (make-list size i) lsts)))
     (let ((lst (apply append lsts))
 	  (vec (apply vector-append vecs))
