@@ -174,35 +174,35 @@
 			    (spaces (+ column 6)))
 			(if (not (pair? (car lst)))
 			    (write (car lst) port)
-			    (let* ((has=> (and (pair? (cdar lst))
-					       (eq? (cadar lst) '=>)))
-				   (extras (and (pair? (cdar lst))
-						(pair? (cddar lst))
-						(or (not has=>)
-						    (pair? (cdddar lst)))))
-				   (too-long (> (length (object->string (cdar lst))) 50)))
-			      (write-char #\( port)
-			      (let ((oldlines newlines))
-				(pretty-print-1 (caar lst) port (+ column 7))
-				(if (or extras 
-					(not (= oldlines newlines))
-					too-long)
-				    (spaces (+ column 7))
-				    (if (and (pair? (cdar lst))
-					     (or (not has=>)
-						 (= oldlines newlines)))
-					(write-char #\space port)))
-				(if (and (pair? (cdar lst))
-					 (not extras)
-					 (not too-long))
-				    (begin
-				      (write (cadar lst) port)
-				      (when has=>
-					(write-char #\space port)
-					(write (caddar lst) port)))
-				    (if (not (null? (cdar lst)))
-					(stacked-list (cdar lst) (+ column 7)))))
-			      (write-char #\) port))))
+			    (let ((has=> (and (pair? (cdar lst))
+					      (eq? (cadar lst) '=>))))
+			      (let ((extras (and (pair? (cdar lst))
+						 (pair? (cddar lst))
+						 (or (not has=>)
+						     (pair? (cdddar lst)))))
+				    (too-long (> (length (object->string (cdar lst))) 50)))
+				(write-char #\( port)
+				(let ((oldlines newlines))
+				  (pretty-print-1 (caar lst) port (+ column 7))
+				  (if (or extras 
+					  (not (= oldlines newlines))
+					  too-long)
+				      (spaces (+ column 7))
+				      (if (and (pair? (cdar lst))
+					       (or (not has=>)
+						   (= oldlines newlines)))
+					  (write-char #\space port)))
+				  (if (and (pair? (cdar lst))
+					   (not extras)
+					   (not too-long))
+				      (begin
+					(write (cadar lst) port)
+					(when has=>
+					  (write-char #\space port)
+					  (write (caddar lst) port)))
+				      (if (not (null? (cdar lst)))
+					  (stacked-list (cdar lst) (+ column 7)))))
+			      (write-char #\) port)))))
 		      (write-char #\) port))
 		     
 		     ((or and)
