@@ -167,7 +167,6 @@
 		 (set! *reverb* reverb-1))))
 
        (let ((start (if statistics (get-internal-real-time)))
-	     (cycles 0)
 	     (revmax #f))
 	 (let ((flush-reverb #f))
 	   (catch 'mus-error
@@ -212,6 +211,7 @@
 	     (mus-close *output*))
 
 	 (let ((snd-output #f)
+	       (cycles 0)
 	       (cur-sync #f))
 	   (if statistics
 	       (set! cycles (* 1.0 (- (get-internal-real-time) start))))
@@ -256,51 +256,53 @@
 			(if revmax (format #f "  rev max: ~,4F~%" revmax) "")
 			cycles)))
 
-	   (when (or scaled-to scaled-by)
-	     (cond (output-to-file
-		    (let* ((scale-output (or snd-output (open-sound output-1)))
-			   (old-sync (sync scale-output)))
-		      (set! (sync scale-output) (+ (sync-max) 1))          ; make sure scaling doesn't follow sync
-		      (if scaled-to
-			  (scale-to scaled-to scale-output)
-			  (scale-by scaled-by scale-output))
-		      (set! (sync scale-output) old-sync)
-		      (save-sound scale-output)
-		      (if (not to-snd) 
-			  (close-sound scale-output))))
-		   
-		   ((float-vector? output-1)
+	   (cond ((not (or scaled-to scaled-by)))
+
+		 (output-to-file
+		  (let* ((scale-output (or snd-output (open-sound output-1)))
+			 (old-sync (sync scale-output)))
+		    (set! (sync scale-output) (+ (sync-max) 1))          ; make sure scaling doesn't follow sync
 		    (if scaled-to
-			(let ((pk (float-vector-peak output-1)))
-			  (if (> pk 0.0)
-			      (float-vector-scale! output-1 (/ scaled-to pk))))
-			(float-vector-scale! output-1 scaled-by)))
-		   
-		   ((not (vector? output-1)))
-		   
-		   (scaled-to
-		    (let ((pk (maxamp output-1)))
-		      (if (> pk 0.0)
-			  (let ((scl (/ scaled-to pk)))
-			    (do ((i 0 (+ i 1)))
-				((= i (length output-1)))
-			      (set! (output-1 i) (* scl (output-1 i))))))))
-		   
-		   (else
-		    (do ((i 0 (+ i 1)))
-			((= i (length output-1)))
-		      (set! (output-1 i) (* scaled-by (output-1 i)))))))
+			(scale-to scaled-to scale-output)
+			(scale-by scaled-by scale-output))
+		    (set! (sync scale-output) old-sync)
+		    (save-sound scale-output)
+		    (if (not to-snd) 
+			(close-sound scale-output))))
+		 
+		 ((float-vector? output-1)
+		  (if scaled-to
+		      (let ((pk (float-vector-peak output-1)))
+			(if (> pk 0.0)
+			    (float-vector-scale! output-1 (/ scaled-to pk))))
+		      (float-vector-scale! output-1 scaled-by)))
+		 
+		 ((not (vector? output-1)))
+		 
+		 (scaled-to
+		  (let ((pk (maxamp output-1)))
+		    (if (> pk 0.0)
+			(let ((scl (/ scaled-to pk)))
+			  (do ((i 0 (+ i 1)))
+			      ((= i (length output-1)))
+			    (set! (output-1 i) (* scl (output-1 i))))))))
+		 
+		 (else
+		  (do ((i 0 (+ i 1)))
+		      ((= i (length output-1)))
+		    (set! (output-1 i) (* scaled-by (output-1 i))))))
 	   
-	   (if (and play output-to-file)
+	   (when output-to-file
+	     (when play
 	       (if to-snd
 		   ((or *clm-player* *default-player*) snd-output)
 		   (*default-player* output-1)))
 
-	   (if (and to-snd output-to-file)
-	       (begin
-		 (update-time-graph snd-output)
-		 (goto-listener-end)
-		 (if (number? cur-sync) (set! (sync snd-output) cur-sync)))))
+	     (when to-snd
+	       (update-time-graph snd-output)
+	       (goto-listener-end)
+	       (if (number? cur-sync) (set! (sync snd-output) cur-sync)))))
+
 	 output-1))
 
      (lambda () 
@@ -633,8 +635,7 @@
 (define (finish-with-sound wsd)
   (if (not (eq? (car wsd) 'with-sound-data))
       (error 'wrong-type-arg (list "finish-with-sound" wsd))
-      (let ((cycles 0)
-	    (output (wsd 1))
+      (let ((output (wsd 1))
 	    (old-srate (wsd 4))
 	    (statistics (wsd 5))
 	    (to-snd (wsd 6))
@@ -657,25 +658,21 @@
 
 	(if (mus-output? *output*)
 	    (mus-close *output*))
-	
-	(if statistics
-	    (set! cycles (/ (- (get-internal-real-time) start) 100)))
 	(if (and to-snd (string? output))
 	    (let ((snd-output (open-sound output)))
 	      (set! (sync snd-output) #t)
 	      (if statistics
-		  (snd-print 
-		   (format #f "~A:~%  maxamp: ~A,~%  compute time: ~A~%"
-			   output
-			   (maxamp snd-output #t)
-			   cycles)))
-		 (if (or scaled-to scaled-by)
-		     (begin
-		       (if scaled-to
-			   (scale-to scaled-to snd-output)
-			   (if scaled-by
-			       (scale-by scaled-by snd-output)))
-		       (save-sound snd-output)))
+		  (snd-print (format #f "~A:~%  maxamp: ~A,~%  compute time: ~A~%"
+				     output
+				     (maxamp snd-output #t)
+				     (/ (- (get-internal-real-time) start) 100))))
+	      (if (or scaled-to scaled-by)
+		  (begin
+		    (if scaled-to
+			(scale-to scaled-to snd-output)
+			(if scaled-by
+			    (scale-by scaled-by snd-output)))
+		    (save-sound snd-output)))
 	      (if play (*default-player* snd-output))
 	      (update-time-graph snd-output)))
 	(set! *clm-srate* old-srate)
@@ -724,21 +721,20 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
       (if (not (symbol? pitch))
 	  pitch
 	  (let* ((name (string-downcase (symbol->string pitch)))
-		 (base-char (name 0))
-		 (sign-char (and (> (length name) 1)
-				 (not (char-numeric? (name 1)))
-				 (not (char=? (name 1) #\n))
-				 (name 1)))
 		 (octave-char (if (and (> (length name) 1)
 				       (char-numeric? (name 1))) 
 				  (name 1)
 				  (and (> (length name) 2) 
 				       (char-numeric? (name 2))
 				       (name 2))))
-		 (base (modulo (- (+ (char->integer base-char) 5) (char->integer #\a)) 7)) ; c-based (diatonic) octaves
-		 (sign (if (not sign-char) 0 (if (char=? sign-char #\f) -1 1)))
+		 (sign-char (and (> (length name) 1)
+				 (not (char-numeric? (name 1)))
+				 (not (char=? (name 1) #\n))
+				 (name 1)))
 		 (octave (if octave-char (- (char->integer octave-char) (char->integer #\0)) last-octave))
-		 (base-pitch (+ sign (case base ((0) 0) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11))))
+		 (base-pitch (let ((base (modulo (- (+ (char->integer (name 0)) 5) (char->integer #\a)) 7)) ; c-based (diatonic) octaves	   
+				   (sign (if (not sign-char) 0 (if (char=? sign-char #\f) -1 1))))
+			       (+ sign (case base ((0) 0) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11)))))
 		 (et-pitch (+ base-pitch (* 12 octave))))
 	    (set! last-octave octave)
 	    (* main-pitch (if pythagorean
@@ -775,20 +771,20 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 	      (list-set! nsym 1 (car old))
 	      (list-set! nsym 0 (list 'quote (car old))))))))
 
-  (let* ((name (if (pair? struct-name) 
-		   (car struct-name) 
-		   struct-name))
-	 (sname (if (string? name) 
-		    name 
-		    (symbol->string name)))
-	 (wrapper (or (and (pair? struct-name)
-			   (or (and (> (length struct-name) 2)
-				    (eq? (struct-name 1) :make-wrapper)
-				    (struct-name 2))
-			       (and (= (length struct-name) 5)
-				    (eq? (struct-name 3) :make-wrapper)
-				    (struct-name 4))))
-		      (lambda (gen) gen)))
+  (let* ((sname (let ((name (if (pair? struct-name) 
+				(car struct-name) 
+				struct-name)))
+		  (if (string? name) 
+		      name 
+		      (symbol->string name))))
+	 (wrapper (let ((wrap (and (pair? struct-name)
+				   (or (and (> (length struct-name) 2)
+					    (eq? (struct-name 1) :make-wrapper)
+					    (struct-name 2))
+				       (and (= (length struct-name) 5)
+					    (eq? (struct-name 3) :make-wrapper)
+					    (struct-name 4))))))
+		    (or wrap (lambda (gen) gen))))
 	 (methods (and (pair? struct-name)
 		       (or (and (> (length struct-name) 2)
 				(eq? (struct-name 1) :methods)
@@ -876,7 +872,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 
 
 (define (mix-notelists . notelists)
-  ;; assume the second parameter is the begin time in seconds (the 1st is the instrument name)
+  ;; assume the second parameter is the begin time in seconds (the first is the instrument name)
   (sort! 
    (apply append notelists)
    (lambda (note1 note2)
