@@ -164,17 +164,17 @@
 	    (set! args (append args (list XmNforeground *data-color*))))
 	(let* ((drawer (XtCreateManagedWidget name xmDrawingAreaWidgetClass parent args))
 	       (gc (car (snd-gcs)))
-	       (x0 (car axis-bounds))
-	       (x1 (cadr axis-bounds)) ; too confusing! -- change internally below
-	       (y0 (caddr axis-bounds))
-	       (y1 (cadddr axis-bounds))
 	       (arrow-cursor (XCreateFontCursor (XtDisplay (cadr (main-widgets))) XC_crosshair))
-	       (editor (list (list x0 y0 x1 y0) ; needs to be in user-coordinates (graph size can change)
-			     drawer 
-			     #f  ; axis pixel locs filled in when drawn
-			     (list x0 y0 x1 y1)
-			     (list gc #f)
-			     name)))
+	       (editor (let ((x0 (car axis-bounds))
+			     (x1 (cadr axis-bounds)) ; too confusing! -- change internally below
+			     (y0 (caddr axis-bounds))
+			     (y1 (cadddr axis-bounds)))
+			 (list (list x0 y0 x1 y0) ; needs to be in user-coordinates (graph size can change)
+			       drawer 
+			       #f  ; axis pixel locs filled in when drawn
+			       (list x0 y0 x1 y1)
+			       (list gc #f)
+			       name))))
 	  (XtAddCallback drawer XmNresizeCallback 
 			 (lambda (w context info) 
 			   (set! (editor 2) (apply draw-axes drawer gc name axis-bounds))
@@ -219,7 +219,7 @@
 			     name))
 	       (dragging #f))
 	  
-	  ;; (xe-create-enved "hi" ((sound-widgets 0) 9) () '(0.0 1.0 0.0 1.0))
+	  ;; (xe-create-enved "hi" ((sound-widgets 0) 9) () '(0.0 1.0 0.0 1.0)) -- this doesn't work?
 	  
 	  (define (local-draw-axes wid gc label x0 x1 y0 y1)
 	    (let* ((cr (make-cairo wid))
@@ -232,63 +232,64 @@
 	  (gtk_widget_show drawer)
 	  (gtk_widget_set_size_request drawer -1 200)
 	  
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "draw" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d)
-							      (set! (editor 2) (apply local-draw-axes drawer gc name axis-bounds))
-							      (xe-redraw editor)
-							      #f)
-							    #f #f)
-					  #f)
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "configure_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d)
-							      (set! (editor 2) (apply local-draw-axes drawer gc name axis-bounds))
-							      (xe-redraw editor)
-							      #f)
-							    #f #f) 
-					  #f)
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "button_press_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d) 
-							      (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
-								(set! dragging #t)
-								(xe-mouse-press editor (cadr coords) (caddr coords)))
-							      #f)
-							    #f #f) 
-					  #f)
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "button_release_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d) 
-							      (set! dragging #f)
-							      (xe-mouse-release editor)
-							      #f)
-							    #f #f)
-					  #f)
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "motion_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d) 
-							      (if dragging
-								  (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
-								    (xe-mouse-drag editor (cadr coords) (caddr coords))))
-							      #f)
-							    #f #f)
-					  #f)
+	  (let ((gf (g_cclosure_new (lambda (w e d)
+				      (set! (editor 2) (apply local-draw-axes drawer gc name axis-bounds))
+				      (xe-redraw editor)
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "draw" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
+	  (let ((gf (g_cclosure_new (lambda (w e d)
+				      (set! (editor 2) (apply local-draw-axes drawer gc name axis-bounds))
+				      (xe-redraw editor)
+				      #f)
+				    #f #f)))
+
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "configure_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
+	  (let ((gf (g_cclosure_new (lambda (w e d) 
+				      (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
+					(set! dragging #t)
+					(xe-mouse-press editor (cadr coords) (caddr coords)))
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "button_press_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
+	  (let ((gf (g_cclosure_new (lambda (w e d) 
+				      (set! dragging #f)
+				      (xe-mouse-release editor)
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "button_release_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
+	  (let ((gf (g_cclosure_new (lambda (w e d) 
+				      (if dragging
+					  (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
+					    (xe-mouse-drag editor (cadr coords) (caddr coords))))
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "motion_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
 	  
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "enter_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d)
-							      (gdk_window_set_cursor (gtk_widget_get_window w) arrow-cursor)
-							      #f)
-							    #f #f)
-					  #f)
-	  (g_signal_connect_closure_by_id (GPOINTER drawer)
-					  (g_signal_lookup "leave_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
-					  0 (g_cclosure_new (lambda (w e d)
-							      (gdk_window_set_cursor (gtk_widget_get_window w) old-cursor)
-							      #f)
-							    #f #f)
-					  #f)
+	  (let ((gf (g_cclosure_new (lambda (w e d)
+				      (gdk_window_set_cursor (gtk_widget_get_window w) arrow-cursor)
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "enter_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
+	  (let ((gf (g_cclosure_new (lambda (w e d)
+				      (gdk_window_set_cursor (gtk_widget_get_window w) old-cursor)
+				      #f)
+				    #f #f)))
+	    (g_signal_connect_closure_by_id (GPOINTER drawer)
+					    (g_signal_lookup "leave_notify_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
+					    0 gf #f))
 	  editor))))
 
 (define (xe-redraw drawer)
@@ -342,26 +343,19 @@
 	      (begin
 		((*motif* 'XClearWindow) dpy wn)
 		(draw-axes widget gc name ix0 ix1 iy0 iy1)
-		(let ((lx #f)
-		      (ly #f))
-		  (do ((i 0 (+ i 2)))
-		      ((= i len))
-		    (let ((cx (xe-grfx (cur-env i)))
-			  (cy (xe-grfy (cur-env (+ i 1)))))
-		      ((*motif* 'XFillArc)
-		       dpy wn gc 
-		       (- cx mouse-r)
-		       (- cy mouse-r)
-		       mouse-d mouse-d
-		       0 23040) ; (* 360 64))
-		      (if lx
-			  ((*motif* 'XDrawLine) dpy wn gc lx ly cx cy))
-		      (set! lx cx)
-		      (set! ly cy)))))
+		(do ((lx #f)
+		     (ly #f)
+		     (i 0 (+ i 2)))
+		    ((= i len))
+		  (let ((cx (xe-grfx (cur-env i)))
+			(cy (xe-grfy (cur-env (+ i 1)))))
+		    ((*motif* 'XFillArc) dpy wn gc (- cx mouse-r) (- cy mouse-r) mouse-d mouse-d 0 23040) ; (* 360 64))
+		    (if lx
+			((*motif* 'XDrawLine) dpy wn gc lx ly cx cy))
+		    (set! lx cx)
+		    (set! ly cy))))
 	      ;; *gtk* 
-	      (let ((lx #f)
-		    (ly #f)
-		    (cr ((*gtk* 'gdk_cairo_create) ((*gtk* 'GDK_WINDOW) wn))))
+	      (let ((cr ((*gtk* 'gdk_cairo_create) ((*gtk* 'GDK_WINDOW) wn))))
 		
 		(let ((size (widget-size ((*gtk* 'GTK_WIDGET) widget))))
 		  ((*gtk* 'cairo_push_group) cr)
@@ -373,7 +367,9 @@
 		
 		((*gtk* 'cairo_set_line_width) cr 1.0)
 		((*gtk* 'cairo_set_source_rgb) cr 0.0 0.0 0.0)
-		(do ((i 0 (+ i 2)))
+		(do ((lx #f)
+		     (ly #f)
+		     (i 0 (+ i 2)))
 		    ((= i len))
 		  (let ((cx (xe-grfx (cur-env i)))
 			(cy (xe-grfy (cur-env (+ i 1)))))
